
selah = ['#405950',
         '#3e242f',
         '#7d4246',
         '#e06865',
         '#f3ad78']

frieda = ['#e6472c',
           '#eed9a1',
           '#93b8b2',
           '#3d2314',
           '#ecd8ae',
           '#35443c']

honeycombe = ['#ce554e',
            '#e29f2d',
            '#a6a78c',
            '#40312b',
            '#e5c794',]

crepuscule = ['#3c8588',
             '#4d3d31',
             '#c5572e',
             '#dbad4e',
             '#efedce',]

juniper = ['#237683',
            '#C9375B',
            '#35477D',
            '#cd5c5c',
            '#FB9E91',
            '#8A6086',
           ]

plath = ['#30343f',
           '#a84b43',
           '#d6b7b5',
           '#30343f']

blonde = ['#edb1a3',
          '#d6543a',
          '#c4bae2',
          '#3c4ebf',
          '#40ada6',
          '#e3a600']

leather = ["#d3772b",
            "#f9edcc",
            "#c32307",
            "#483d8b",
            "#7d939a",
          ]

gucci = ['#e8b789',
         '#046a50',
         '#ddb65f',
         '#26183a',
         '#e81f05']

sandbar = ['#000000',
         '#a1d9da',
         '#d1923f',
         '#025e8f',
         '#e9c5a5']

fiestaware = ['#ab0b11',
              '#e27a00',
              '#36a3c2',
              '#dfcd00',
              '#5a006e']

chilaquiles = ['#749e81',
               '#821b07',
               '#01300d',
               '#d3af03']

eleven = ['#c65f25',
          '#4c0c0a',
          '#fc5659',
          '#efb36e',
          '#6487cc']

splenda = ['#6487cc',
           '#d49a8e',
           '#c0c7f6',
           '#e396bd']

gremlin = ['#3a5b84',
           '#9d2020',
           '#2b2b2b',
           '#836a00',
           '#002c59']

pollen = ['#fB9e91',
          '#604d89',
          '#f5f0e3',
          '#b4b6d8',
          '#ffd082']

bollen = ['#eB8e81',
        '#503d79',
        '#c1b6b2',
        '#a9b0d0',
        '#efc072']

medium = ['#e3a201',
          '#6762ab',
          '#d55101',
          '#0d936a']

juniper = [ "#216583",
            '#6C567B',
            "#D1274B",
            '#35477D',
            "#cd5c5c",
            "#FB9E91",
            ]

polya = ["#A43955",
         "#2C2B26",
         "#6A6B5F",
         "#738C79",
         "#ECBE13"]

ostrich = ['#ee5500', 'teal', 'midnightblue', '#d45d79'] # TURN ALPHA ON

quinone =  [
            "#991a40",
            "#1c0517",
            "#9db0bb",
            "#ae3f03",
            (210, 150, 160)
           ]

quinoline = [
            "#B22c56",
            "#2c1527",
            "#ca6f13",
            (225, 170, 170),
           ]

fraiche = ['#472b62',
           "#f5f0e3",
          '#bc4873',
           "#222222",
           '#fb5b5a',
      ]

cheshire=['#730068',
         '#347474',
         '#470938',
         '#1a3e59',
         '#b21f66',
         '#111d5e',]

carmine = [
    'maroon',
    "#f0f0f0",
    "#222222",
    'lightcoral',
    'indianred',
    'firebrick',
    ]

joan = ['#166161',
        '#0e3244',
        '#c4ad75',
        '#e3dac5',
        '#0a152e']

joan256 = ['#0a152e',
 '#0a152e',
 '#0a162e',
 '#0a162f',
 '#0a172f',
 '#0a1730',
 '#0a1830',
 '#0a1931',
 '#0a1931',
 '#0a1a31',
 '#0a1a32',
 '#0a1b32',
 '#0a1b33',
 '#0b1c33',
 '#0b1d34',
 '#0b1d34',
 '#0b1e35',
 '#0b1e35',
 '#0b1f35',
 '#0b2036',
 '#0b2036',
 '#0b2137',
 '#0b2137',
 '#0b2238',
 '#0b2238',
 '#0c2339',
 '#0c2439',
 '#0c2439',
 '#0c253a',
 '#0c253a',
 '#0c263b',
 '#0c263b',
 '#0c273c',
 '#0c283c',
 '#0c283c',
 '#0c293d',
 '#0c293d',
 '#0c2a3e',
 '#0d2b3e',
 '#0d2b3f',
 '#0d2c3f',
 '#0d2c40',
 '#0d2d40',
 '#0d2d40',
 '#0d2e41',
 '#0d2f41',
 '#0d2f42',
 '#0d3042',
 '#0d3043',
 '#0d3143',
 '#0e3244',
 '#0e3244',
 '#0e3345',
 '#0e3445',
 '#0e3546',
 '#0e3646',
 '#0e3747',
 '#0f3848',
 '#0f3948',
 '#0f3a49',
 '#0f3b49',
 '#0f3c4a',
 '#0f3d4a',
 '#103e4b',
 '#103f4c',
 '#10404c',
 '#10414d',
 '#10414d',
 '#10424e',
 '#11434f',
 '#11444f',
 '#114550',
 '#114650',
 '#114751',
 '#114851',
 '#124952',
 '#124a53',
 '#124b53',
 '#124c54',
 '#124d54',
 '#124e55',
 '#124f55',
 '#135056',
 '#135157',
 '#135157',
 '#135258',
 '#135358',
 '#135459',
 '#14555a',
 '#14565a',
 '#14575b',
 '#14585b',
 '#14595c',
 '#145a5c',
 '#155b5d',
 '#155c5e',
 '#155d5e',
 '#155e5f',
 '#155f5f',
 '#156060',
 '#166161',
 '#196261',
 '#1c6461',
 '#206562',
 '#236762',
 '#276863',
 '#2a6a63',
 '#2e6b63',
 '#316d64',
 '#356e64',
 '#387065',
 '#3c7165',
 '#3f7365',
 '#437466',
 '#467666',
 '#4a7767',
 '#4d7967',
 '#517a67',
 '#547c68',
 '#587d68',
 '#5b7f69',
 '#5f8069',
 '#628269',
 '#66836a',
 '#69856a',
 '#6d876b',
 '#70886b',
 '#738a6b',
 '#778b6c',
 '#7a8d6c',
 '#7e8e6d',
 '#81906d',
 '#85916d',
 '#88936e',
 '#8c946e',
 '#8f966f',
 '#93976f',
 '#96996f',
 '#9a9a70',
 '#9d9c70',
 '#a19d71',
 '#a49f71',
 '#a8a071',
 '#aba272',
 '#afa372',
 '#b2a573',
 '#b6a673',
 '#b9a873',
 '#bda974',
 '#c0ab74',
 '#c4ad75',
 '#c4ad76',
 '#c5ae77',
 '#c5af78',
 '#c6b079',
 '#c7b17a',
 '#c7b27b',
 '#c8b37c',
 '#c8b47d',
 '#c9b57e',
 '#cab680',
 '#cab781',
 '#cbb882',
 '#ccb983',
 '#ccba84',
 '#cdbb85',
 '#cdbc86',
 '#cebd87',
 '#cfbe88',
 '#cfbf89',
 '#d0c08b',
 '#d1c18c',
 '#d1c28d',
 '#d2c38e',
 '#d2c48f',
 '#d3c590',
 '#d4c591',
 '#d4c692',
 '#d5c793',
 '#d5c894',
 '#d6c996',
 '#d7ca97',
 '#d7cb98',
 '#d8cc99',
 '#d9cd9a',
 '#d9ce9b',
 '#dacf9c',
 '#dad09d',
 '#dbd19e',
 '#dcd29f',
 '#dcd3a1',
 '#ddd4a2',
 '#ded5a3',
 '#ded6a4',
 '#dfd7a5',
 '#dfd8a6',
 '#e0d9a7',
 '#e1daa8',
 '#e1dba9',
 '#e2dcaa',
 '#e3ddac',
 '#e3ddad',
 '#e4deaf',
 '#e4dfb0',
 '#e5dfb2',
 '#e5e0b4',
 '#e6e1b5',
 '#e6e1b7',
 '#e7e2b9',
 '#e8e3ba',
 '#e8e3bc',
 '#e9e4be',
 '#e9e5bf',
 '#eae5c1',
 '#eae6c3',
 '#ebe7c4',
 '#ebe7c6',
 '#ece8c8',
 '#ede9c9',
 '#ede9cb',
 '#eeeacd',
 '#eeebce',
 '#efebd0',
 '#efecd2',
 '#f0edd3',
 '#f1eed5',
 '#f1eed7',
 '#f2efd8',
 '#f2f0da',
 '#f3f0dc',
 '#f3f1dd',
 '#f4f2df',
 '#f4f2e1',
 '#f5f3e2',
 '#f6f4e4',
 '#f6f4e6',
 '#f7f5e7',
 '#f7f6e9',
 '#f8f6eb',
 '#f8f7ec',
 '#f9f8ee',
 '#f9f8f0',
 '#faf9f1',
 '#fbfaf3',
 '#fbfaf5',
 '#fcfbf6',
 '#fcfcf8',
 '#fdfcfa',
 '#fdfdfb',
 '#fefefd',
 '#ffffff']

pinot = ['#9e1b3e',
         '#bdc9a9',
         '#908474',
         '#613d4c',
         '#27162f']

addams = ['#9faeb2',
          '#ab6e7d',
          '#1c2630']

minuit = ['#180d56',
          '#282985',
          '#3c9496',
          '#e36d25',
          '#98133c',
          '#d85156']

fugazi = ['#000208',
          '#a49b87',
          '#ece6d3',
          '#04133f',
          '#ca4138']

clementine = ['#fa4c49',
              '#faf5d7',
              '#37848e',
              '#faa851',
              '#0b2a45',
              '#0d0432']

leda=['#2c2f30',
      '#8fa7d7',
      '#afd7d6',
      '#aa3751',
      '#f5b3b8']

pugsley = ['#eadca3',
           '#679181',
           '#450301',
           '#911501',
           '#07093e']

bellhooks = ['#facab6',
             '#b38577',
             '#d66f31',
             '#2e211f']

wes = ['#d7adad',
       '#94afbf',
       '#1c2630',
       '#aa352e',
       '#6b7b75',
       '#4a4634',
      ]

lysergic = ['#4d53b5',
        '#011b5a',
        '#238cb5',
        '#75bcbd',
        '#b92c60']

pepo = ['#29937b',
             '#044032',
             '#902a42',
             '#3f0914',
             '#e4607c']

reese =["#300a19",
        "#d89f21",
        "#a94434",
        "#bc6333",
        "#d896b0",]

lufte = ["#9fc0c1",
         "#eba8b5",
         "#65042d",
         "#714c36"]

oolong = ['#977500',
          '#f9f2c1',
          '#ffc670',
          '#bf033f',
          '#ae3f03',
          '#896056']

pitaya = ["#cb4f70",
          "#1b718c",
          "#779e1a",
          "#f49044"]

alice = ["#52357b",
        "#301b4f",
        "#b03653",
        "#966da1",]

neko = ['#b85e00',
        '#f59994',
        "#c0b490",
        "#0d2b52"]

belle = [ "#b8131a",
         "#ffb82b",
         "#dd0336",
         "#e9d1a5",
         "#792159" ]

spiff = ["#46308d",
         "#2ea58e",
         "#e97d86",
         "#7e92bd"]

yoshi = ["#111129",
         "#228dc3",
         "#cd355c",
         "#d0e44e"]

phoebe = ['#1c0517',
          '#8ba794',
          '#ee5f8e',
          '#fde4d1',
          '#991a40',]

pam = ["#634131",
       "#448168",
       "#d0726f",
       "#5e7235",
       "#e1d281"]

menthol = ["#f40505",
           "#c8eaea",
           "#020437",
           "#e4ebe9",
           "#f7bc25"]

dwight = [(135, 36, 36),
            '#9dab86',
            (193,142, 142),
            (216, 180,180)
         ]

riley = ['#66c2a5',
         '#fc8d62',
         '#8da0cb',
         '#e78ac3',
         '#a6d854']

mona = ['#9a1024',
        '#d14f1e',
        "#f6e5d1",
        "#819d66",
        "#4f1c36"]

eeyore = ["#6d93b3",
          "#eba516",
          "#de9586",
          "#8bb046"]

rainbow = ['#c21019',
           '#f56327',
           "#fab01d",
           '#026f69',
           '#750a2b']

rory = ["#9D7E6A",
      "#3E2406",
      "#C05A48",
      "#A2A928",
      "#D2B153",
      "#669A8B",]

pudding = ["#84B5B2",
           "#5779A3",
           "#D1605E",
           "#E59244",]

marmalade = ["#D8862E",
            "#C54927",
            "#558F6A",
            "#DBAE4B",
            "#9EAA3F",
            "#373D44",
            "#95A99B"]

polaris = ["#060606",
            "#EBACA2",
            "#444F4A",
            "#D6E0E0",
            "#667276",
            "#AD6863"]

trefoil = ["#D16D60",
            "#60A9AB",
            "#1F1D34"]

harmon = ["#6471E2",
          "#D33860",
          "#222D50",
          "#DA6644",
          "#75CDF3"]

abed = ["#D86B19",
        "#866D9E",
        "#B2C15C",
        "#B65951",
        "#6C8ABB"]

shirley = ["#3a809c",
           "#924197",
           "#8d72cf",
           "#55279b",]

surely = ["#5f97ac",
          "#a466a8",
          "#a18dd4",
          "#5064a4",]

annie = ["#D16D60",
         "#60A9AB",
         "#E6B7B9",
         "#8E9281",
         "#1F1D34"]

pierce = ["#6A87C4",
         "#040404",
         "#D2946A",
         "#B43941",
         "#7A564D",
         "#E2C06E"]

britta = ["#af4858",
          "#91a200",
          "#363304",
          "#65a99f"]

strogatz = ["#C85158",
            "#62A48F",
            "#475A7A",
            "#503A38",
            "#E9AD97",
            "#88A4BA",]

lutz = ["#B26169", #"#A25159",
        "#616BA0",
        "#628787",
        "#909C5B", ]

writhe = ["#12183E",
          "#4A5970",
          "#932438",
          "#C85558",
          "#EFC9A1",
          "#79637D"]

perl = ["#D4B3CF",
        "#808BBE",
        "#B09DC9",
        "#74A0B2",
        "#1C2641",
        "#325676"]

diverging = ['#cb4f70',
            '#1b718c',
            '#779e1a',
            '#f49044',
            '#46308d',
            '#2ea58e',
            '#e97d86',
            '#7e92bd',
            '#c21019',
            '#f56327',
            '#fab01d',
            '#026f69',
            '#750a2b',
            '#1b9e77',
            '#d95f02',
            '#7570b3',
            '#e7298a',
            '#66a61e']

bluefish = ['#000080',
            '#1b0e7e',
            '#371c7c',
            '#532a7b',
            '#6f3879',
            '#8a4778',
            '#a65576',
            '#c26375',
            '#de7173',
            '#fa8072']

peanuts = ["#d11026",
            "#f0a46b",
            "#000221"]

naval = ["navy",
        "darkorange",
        "#a6b1e1"]

maggie = ["#091622",
          "#790C03",
          "#d9906c",
          "#C0340D",
          "#838472",
          "#feca82",
          ]

indomie = ['#ab5439',
           '#cfa26b',
           '#728162',
           '#adafad',
           '#552d1d',
           '#e5ded5',]

moonbow = ["#FF657A",
            "#FF9B5E",
            "#FFD76D",
            "#9CD1BB",
            "#BAD761",
            "#C29AC8",
            "#888D94"]

roosh = ['#b2a9b1',
        '#3b8988',
        '#00104b',
        '#a54a5c',
        '#65658e']

seafare = ['#d5622b',
            '#153c63',
            '#5cb8d8',
            '#f0f5f4',
            '#317497']

heliotrope = ['#f3b8c1',
            '#4a1248',
            '#8c85d1',
            '#171d6b',
            '#cd9fba']

perl256 = ['#1c2641',
 '#1c2742',
 '#1d2843',
 '#1d2944',
 '#1e2a46',
 '#1e2b47',
 '#1f2d48',
 '#1f2e4a',
 '#202f4b',
 '#20304c',
 '#21314d',
 '#21324f',
 '#223450',
 '#223551',
 '#233653',
 '#243754',
 '#243855',
 '#253956',
 '#253b58',
 '#263c59',
 '#263d5a',
 '#273e5c',
 '#273f5d',
 '#28405e',
 '#284260',
 '#294361',
 '#294462',
 '#2a4563',
 '#2b4665',
 '#2b4766',
 '#2c4967',
 '#2c4a69',
 '#2d4b6a',
 '#2d4c6b',
 '#2e4d6c',
 '#2e4e6e',
 '#2f506f',
 '#2f5170',
 '#305272',
 '#305373',
 '#315474',
 '#325676',
 '#335777',
 '#355978',
 '#365b7a',
 '#385d7b',
 '#3a5f7d',
 '#3b607e',
 '#3d6280',
 '#3e6481',
 '#406683',
 '#426884',
 '#436986',
 '#456b87',
 '#466d89',
 '#486f8a',
 '#4a718b',
 '#4b728d',
 '#4d748e',
 '#4e7690',
 '#507891',
 '#527a93',
 '#537b94',
 '#557d96',
 '#577f97',
 '#588199',
 '#5a839a',
 '#5b849c',
 '#5d869d',
 '#5f889e',
 '#608aa0',
 '#628ca1',
 '#638da3',
 '#658fa4',
 '#6791a6',
 '#6893a7',
 '#6a95a9',
 '#6b96aa',
 '#6d98ac',
 '#6f9aad',
 '#709caf',
 '#729eb0',
 '#74a0b2',
 '#76a0b2',
 '#78a0b3',
 '#7ba1b4',
 '#7da1b4',
 '#7fa2b5',
 '#82a2b6',
 '#84a3b6',
 '#86a3b7',
 '#89a4b8',
 '#8ba4b9',
 '#8da5b9',
 '#90a5ba',
 '#92a6bb',
 '#94a6bb',
 '#97a6bc',
 '#99a7bd',
 '#9ba7be',
 '#9ea8be',
 '#a0a8bf',
 '#a2a9c0',
 '#a5a9c0',
 '#a7aac1',
 '#a9aac2',
 '#acabc2',
 '#aeabc3',
 '#b0acc4',
 '#b3acc5',
 '#b5acc5',
 '#b7adc6',
 '#baadc7',
 '#bcaec7',
 '#beaec8',
 '#c1afc9',
 '#c3afca',
 '#c5b0ca',
 '#c8b0cb',
 '#cab1cc',
 '#ccb1cc',
 '#cfb2cd',
 '#d1b2ce',
 '#d4b3cf',
 '#d3b2ce',
 '#d2b1ce',
 '#d1b1ce',
 '#d0b0ce',
 '#cfb0ce',
 '#ceafce',
 '#cdafcd',
 '#ccaecd',
 '#ccaecd',
 '#cbadcd',
 '#caadcd',
 '#c9accd',
 '#c8accd',
 '#c7abcc',
 '#c6aacc',
 '#c5aacc',
 '#c5a9cc',
 '#c4a9cc',
 '#c3a8cc',
 '#c2a8cc',
 '#c1a7cb',
 '#c0a7cb',
 '#bfa6cb',
 '#bea6cb',
 '#bea5cb',
 '#bda5cb',
 '#bca4cb',
 '#bba3ca',
 '#baa3ca',
 '#b9a2ca',
 '#b8a2ca',
 '#b7a1ca',
 '#b7a1ca',
 '#b6a0ca',
 '#b5a0c9',
 '#b49fc9',
 '#b39fc9',
 '#b29ec9',
 '#b19ec9',
 '#b09dc9',
 '#b09dc9',
 '#ae9cc8',
 '#ad9cc8',
 '#ac9bc8',
 '#ab9bc7',
 '#aa9ac7',
 '#a89ac7',
 '#a799c7',
 '#a699c6',
 '#a599c6',
 '#a498c6',
 '#a398c6',
 '#a197c5',
 '#a097c5',
 '#9f96c5',
 '#9e96c4',
 '#9d95c4',
 '#9c95c4',
 '#9a95c4',
 '#9994c3',
 '#9894c3',
 '#9793c3',
 '#9693c3',
 '#9592c2',
 '#9392c2',
 '#9292c2',
 '#9191c2',
 '#9091c1',
 '#8f90c1',
 '#8e90c1',
 '#8c8fc0',
 '#8b8fc0',
 '#8a8ec0',
 '#898ec0',
 '#888ebf',
 '#878dbf',
 '#858dbf',
 '#848cbf',
 '#838cbe',
 '#828bbe',
 '#818bbe',
 '#808bbe',
 '#7e89bd',
 '#7d88bd',
 '#7c87bc',
 '#7b86bc',
 '#7a85bc',
 '#7883bb',
 '#7782bb',
 '#7681ba',
 '#7580ba',
 '#747fba',
 '#737eb9']

orb = ['#1e2422',
       '#414146',
       '#4f626b',
       '#926970',
       '#d2827d',
       '#e7cac6']

orb256 = ['#0f1211',
 '#101312',
 '#111413',
 '#121514',
 '#121615',
 '#131716',
 '#141817',
 '#151918',
 '#161a19',
 '#171b1a',
 '#181c1b',
 '#181d1c',
 '#191e1d',
 '#1a1f1e',
 '#1b201f',
 '#1c2120',
 '#1d2221',
 '#1e2422',
 '#1f2423',
 '#202524',
 '#212625',
 '#222726',
 '#232827',
 '#242828',
 '#252929',
 '#262a2a',
 '#272b2b',
 '#282c2c',
 '#292d2d',
 '#2a2d2e',
 '#2b2e2f',
 '#2c2f30',
 '#2d3031',
 '#2e3132',
 '#2f3233',
 '#303234',
 '#313335',
 '#323436',
 '#333537',
 '#343638',
 '#353739',
 '#36373a',
 '#37383b',
 '#38393c',
 '#393a3d',
 '#3a3b3e',
 '#3b3c3f',
 '#3c3c40',
 '#3d3d41',
 '#3e3e42',
 '#3f3f43',
 '#404044',
 '#414146',
 '#414147',
 '#414248',
 '#424349',
 '#42444a',
 '#43454b',
 '#43464c',
 '#43474d',
 '#44484e',
 '#44494f',
 '#454a50',
 '#454b51',
 '#454c52',
 '#464d53',
 '#464e54',
 '#474f55',
 '#475056',
 '#475157',
 '#485159',
 '#48525a',
 '#49535b',
 '#49545c',
 '#49555d',
 '#4a565e',
 '#4a575f',
 '#4b5860',
 '#4b5961',
 '#4b5a62',
 '#4c5b63',
 '#4c5c64',
 '#4d5d65',
 '#4d5e66',
 '#4d5f67',
 '#4e6068',
 '#4e6169',
 '#4f626b',
 '#50626b',
 '#52626b',
 '#54626b',
 '#56626b',
 '#58636b',
 '#5a636b',
 '#5c636c',
 '#5e636c',
 '#60636c',
 '#62646c',
 '#64646c',
 '#65646c',
 '#67646c',
 '#69646d',
 '#6b656d',
 '#6d656d',
 '#6f656d',
 '#71656d',
 '#73656d',
 '#75666d',
 '#77666e',
 '#79666e',
 '#7b666e',
 '#7c666e',
 '#7e676e',
 '#80676e',
 '#82676e',
 '#84676f',
 '#86676f',
 '#88686f',
 '#8a686f',
 '#8c686f',
 '#8e686f',
 '#90686f',
 '#926970',
 '#936970',
 '#956a70',
 '#976b71',
 '#996b71',
 '#9b6c71',
 '#9c6d72',
 '#9e6e72',
 '#a06e72',
 '#a26f73',
 '#a47073',
 '#a67074',
 '#a77174',
 '#a97274',
 '#ab7375',
 '#ad7375',
 '#af7475',
 '#b17576',
 '#b27576',
 '#b47677',
 '#b67777',
 '#b87877',
 '#ba7878',
 '#bc7978',
 '#bd7a78',
 '#bf7a79',
 '#c17b79',
 '#c37c7a',
 '#c57d7a',
 '#c77d7a',
 '#c87e7b',
 '#ca7f7b',
 '#cc7f7b',
 '#ce807c',
 '#d0817c',
 '#d2827d',
 '#d2847f',
 '#d38681',
 '#d38883',
 '#d48a85',
 '#d58c87',
 '#d58e89',
 '#d6908b',
 '#d6928d',
 '#d7948f',
 '#d89691',
 '#d89893',
 '#d99a96',
 '#d99c98',
 '#da9e9a',
 '#dba09c',
 '#dba29e',
 '#dca4a0',
 '#dca7a2',
 '#dda9a4',
 '#deaba6',
 '#deada8',
 '#dfafaa',
 '#dfb1ac',
 '#e0b3af',
 '#e1b5b1',
 '#e1b7b3',
 '#e2b9b5',
 '#e2bbb7',
 '#e3bdb9',
 '#e4bfbb',
 '#e4c1bd',
 '#e5c3bf',
 '#e5c5c1',
 '#e6c7c3',
 '#e7cac6',
 '#e7cbc7',
 '#e7ccc8',
 '#e7cdc9',
 '#e7ceca',
 '#e8cfcb',
 '#e8d0cc',
 '#e8d1ce']

joker = ["#133d3c",
        "#30706e",
        "#73a8bc",
        "#d5d3e7",
        "#ba9bc3",
        "#795dab",
        "#4b338d"]
joker256 = ['#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133d3c',
 '#133e3d',
 '#14403f',
 '#154140',
 '#164342',
 '#174544',
 '#184645',
 '#194847',
 '#1a4a48',
 '#1b4b4a',
 '#1c4d4c',
 '#1d4f4d',
 '#1e504f',
 '#1f5250',
 '#205452',
 '#215554',
 '#215755',
 '#225857',
 '#235a59',
 '#245c5a',
 '#255d5c',
 '#265f5d',
 '#27615f',
 '#286261',
 '#296462',
 '#2a6664',
 '#2b6765',
 '#2c6967',
 '#2d6b69',
 '#2e6c6a',
 '#2f6e6c',
 '#30706e',
 '#327170',
 '#347373',
 '#367575',
 '#387778',
 '#3a797a',
 '#3c7a7d',
 '#3f7c7f',
 '#417e82',
 '#438084',
 '#458287',
 '#478389',
 '#49858c',
 '#4c878e',
 '#4e8991',
 '#508b93',
 '#528c96',
 '#548e98',
 '#56909b',
 '#59929d',
 '#5b94a0',
 '#5d95a2',
 '#5f97a5',
 '#6199a7',
 '#639baa',
 '#669dac',
 '#689eaf',
 '#6aa0b1',
 '#6ca2b4',
 '#6ea4b6',
 '#70a6b9',
 '#73a8bc',
 '#76a9bd',
 '#79aabe',
 '#7cacc0',
 '#7fadc1',
 '#82aec2',
 '#85b0c4',
 '#89b1c5',
 '#8cb3c7',
 '#8fb4c8',
 '#92b5c9',
 '#95b7cb',
 '#98b8cc',
 '#9cbace',
 '#9fbbcf',
 '#a2bcd0',
 '#a5bed2',
 '#a8bfd3',
 '#abc0d4',
 '#afc2d6',
 '#b2c3d7',
 '#b5c5d9',
 '#b8c6da',
 '#bbc7db',
 '#bec9dd',
 '#c2cade',
 '#c5cce0',
 '#c8cde1',
 '#cbcee2',
 '#ced0e4',
 '#d1d1e5',
 '#d5d3e7',
 '#d4d1e5',
 '#d3cfe4',
 '#d2cde3',
 '#d1cbe2',
 '#d0c9e1',
 '#cfc8e0',
 '#cec6de',
 '#cec4dd',
 '#cdc2dc',
 '#ccc0db',
 '#cbbfda',
 '#cabdd9',
 '#c9bbd7',
 '#c8b9d6',
 '#c7b7d5',
 '#c7b6d4',
 '#c6b4d3',
 '#c5b2d2',
 '#c4b0d0',
 '#c3aecf',
 '#c2adce',
 '#c1abcd',
 '#c0a9cc',
 '#c0a7cb',
 '#bfa5c9',
 '#bea4c8',
 '#bda2c7',
 '#bca0c6',
 '#bb9ec5',
 '#ba9cc4',
 '#ba9bc3',
 '#b799c2',
 '#b597c1',
 '#b395c0',
 '#b193bf',
 '#af91bf',
 '#ad8fbe',
 '#ab8dbd',
 '#a98bbc',
 '#a789bc',
 '#a587bb',
 '#a285ba',
 '#a083b9',
 '#9e81b8',
 '#9c7fb8',
 '#9a7db7',
 '#987bb6',
 '#9679b5',
 '#9477b5',
 '#9275b4',
 '#9073b3',
 '#8d71b2',
 '#8b6fb1',
 '#896db1',
 '#876bb0',
 '#8569af',
 '#8367ae',
 '#8165ae',
 '#7f63ad',
 '#7d61ac',
 '#7b5fab',
 '#795dab',
 '#775baa',
 '#765aa9',
 '#7458a8',
 '#7357a7',
 '#7156a6',
 '#7054a5',
 '#6e53a4',
 '#6d52a3',
 '#6b50a2',
 '#6a4fa1',
 '#684ea0',
 '#674c9f',
 '#654b9e',
 '#644a9d',
 '#62489c',
 '#61479b',
 '#5f459a',
 '#5e4499',
 '#5c4398',
 '#5b4197',
 '#594096',
 '#583f95',
 '#563d94',
 '#553c93',
 '#533b92',
 '#523991',
 '#503890',
 '#4f378f',
 '#4d358e',
 '#4c348d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d',
 '#4b338d']

rach = ["#3e2541",
        "#66334f",
        "#9e5a6b",
        "#c19aac",
        "#cdd8dc",
        "#8baab5",
        "#6e90a3",
        "#385264"]
rach256 = ['#3e2541',
 '#3e2541',
 '#3e2541',
 '#3e2541',
 '#3e2541',
 '#3e2541',
 '#3e2541',
 '#3e2541',
 '#3f2541',
 '#402642',
 '#422642',
 '#432743',
 '#452743',
 '#462844',
 '#482844',
 '#492945',
 '#4b2945',
 '#4c2a46',
 '#4e2a46',
 '#4f2b47',
 '#512b47',
 '#522c48',
 '#542c48',
 '#552d49',
 '#572d49',
 '#582e4a',
 '#5a2e4a',
 '#5b2f4b',
 '#5d2f4b',
 '#5e304c',
 '#60304c',
 '#61314d',
 '#63314d',
 '#64324e',
 '#66334f',
 '#683450',
 '#6a3551',
 '#6c3752',
 '#6e3853',
 '#703a54',
 '#723b55',
 '#743d56',
 '#763e57',
 '#784058',
 '#7a4159',
 '#7c425a',
 '#7e445b',
 '#80455c',
 '#83475d',
 '#85485e',
 '#874a5f',
 '#894b60',
 '#8b4d61',
 '#8d4e62',
 '#8f4f63',
 '#915164',
 '#935265',
 '#955466',
 '#975567',
 '#995768',
 '#9b5869',
 '#9e5a6b',
 '#9f5c6d',
 '#a05e6f',
 '#a16172',
 '#a36374',
 '#a46577',
 '#a56879',
 '#a76a7b',
 '#a86c7e',
 '#a96f80',
 '#aa7183',
 '#ac7485',
 '#ad7687',
 '#ae788a',
 '#b07b8c',
 '#b17d8f',
 '#b27f91',
 '#b48293',
 '#b58496',
 '#b68798',
 '#b7899b',
 '#b98b9d',
 '#ba8e9f',
 '#bb90a2',
 '#bd92a4',
 '#be95a7',
 '#bf97a9',
 '#c19aac',
 '#c19cad',
 '#c19eaf',
 '#c2a0b1',
 '#c2a3b3',
 '#c3a5b4',
 '#c3a7b6',
 '#c4aab8',
 '#c4acba',
 '#c5aebc',
 '#c5b0bd',
 '#c5b3bf',
 '#c6b5c1',
 '#c6b7c3',
 '#c7bac4',
 '#c7bcc6',
 '#c8bec8',
 '#c8c1ca',
 '#c9c3cc',
 '#c9c5cd',
 '#c9c7cf',
 '#cacad1',
 '#caccd3',
 '#cbced4',
 '#cbd1d6',
 '#ccd3d8',
 '#ccd5da',
 '#cdd8dc',
 '#cad6da',
 '#c8d4d9',
 '#c5d2d7',
 '#c3d1d6',
 '#c0cfd4',
 '#becdd3',
 '#bbccd1',
 '#b9cad0',
 '#b7c8cf',
 '#b4c6cd',
 '#b2c5cc',
 '#afc3ca',
 '#adc1c9',
 '#aac0c7',
 '#a8bec6',
 '#a5bcc4',
 '#a3bbc3',
 '#a1b9c2',
 '#9eb7c0',
 '#9cb5bf',
 '#99b4bd',
 '#97b2bc',
 '#94b0ba',
 '#92afb9',
 '#8fadb7',
 '#8dabb6',
 '#8baab5',
 '#89a9b4',
 '#88a8b3',
 '#87a7b3',
 '#86a6b2',
 '#85a5b1',
 '#84a4b1',
 '#83a3b0',
 '#82a2af',
 '#81a1af',
 '#80a0ae',
 '#7f9fad',
 '#7e9ead',
 '#7d9dac',
 '#7b9cab',
 '#7a9bab',
 '#799aaa',
 '#7899a9',
 '#7798a9',
 '#7697a8',
 '#7596a7',
 '#7495a7',
 '#7394a6',
 '#7293a5',
 '#7192a5',
 '#7091a4',
 '#6f90a3',
 '#6e90a3',
 '#6c8da0',
 '#6a8b9e',
 '#68899c',
 '#668699',
 '#648497',
 '#628295',
 '#607f92',
 '#5e7d90',
 '#5c7b8e',
 '#5a798b',
 '#587689',
 '#567487',
 '#547284',
 '#526f82',
 '#506d80',
 '#4e6b7d',
 '#4c687b',
 '#4a6679',
 '#486476',
 '#466274',
 '#445f72',
 '#425d6f',
 '#405b6d',
 '#3e586b',
 '#3c5668',
 '#3a5466',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264',
 '#385264']

BuPu9 = ['#4d004b',
        '#810f7c',
        '#88419d',
        '#8c6bb1',
        '#8c96c6',
        '#9ebcda',
        '#bfd3e6',
        '#e0ecf4',
        '#f7fcfd']
holst = BuPu256 = ['#310030',
                '#320031',
                '#330032',
                '#340033',
                '#350034',
                '#360035',
                '#370036',
                '#380037',
                '#390038',
                '#3a0039',
                '#3b003a',
                '#3c003b',
                '#3d003c',
                '#3e003d',
                '#3f003e',
                '#40003f',
                '#410040',
                '#420041',
                '#430042',
                '#440043',
                '#450044',
                '#460045',
                '#470046',
                '#480047',
                '#490048',
                '#4a0049',
                '#4b004a',
                '#4d004b',
                '#4e004c',
                '#50014e',
                '#520150',
                '#540252',
                '#560254',
                '#580355',
                '#5a0357',
                '#5c0459',
                '#5e055b',
                '#60055d',
                '#62065e',
                '#640660',
                '#660762',
                '#670764',
                '#690866',
                '#6b0868',
                '#6d0969',
                '#6f0a6b',
                '#710a6d',
                '#730b6f',
                '#750b71',
                '#770c72',
                '#790c74',
                '#7b0d76',
                '#7d0d78',
                '#7f0e7a',
                '#810f7c',
                '#81107d',
                '#81127e',
                '#81147f',
                '#821680',
                '#821882',
                '#821a83',
                '#821b84',
                '#831d85',
                '#831f87',
                '#832188',
                '#832389',
                '#84258a',
                '#84278b',
                '#84288d',
                '#842a8e',
                '#852c8f',
                '#852e90',
                '#853092',
                '#853293',
                '#863494',
                '#863595',
                '#863796',
                '#863998',
                '#873b99',
                '#873d9a',
                '#873f9b',
                '#88419d',
                '#88429d',
                '#88449e',
                '#88459f',
                '#88479f',
                '#8848a0',
                '#884aa1',
                '#894ba2',
                '#894da2',
                '#894fa3',
                '#8950a4',
                '#8952a5',
                '#8953a5',
                '#8955a6',
                '#8a56a7',
                '#8a58a8',
                '#8a59a8',
                '#8a5ba9',
                '#8a5daa',
                '#8a5eab',
                '#8a60ab',
                '#8b61ac',
                '#8b63ad',
                '#8b64ae',
                '#8b66ae',
                '#8b67af',
                '#8b69b0',
                '#8c6bb1',
                '#8c6cb1',
                '#8c6eb2',
                '#8c6fb3',
                '#8c71b4',
                '#8c72b4',
                '#8c74b5',
                '#8c76b6',
                '#8c77b7',
                '#8c79b8',
                '#8c7ab8',
                '#8c7cb9',
                '#8c7eba',
                '#8c7fbb',
                '#8c81bb',
                '#8c82bc',
                '#8c84bd',
                '#8c86be',
                '#8c87bf',
                '#8c89bf',
                '#8c8ac0',
                '#8c8cc1',
                '#8c8ec2',
                '#8c8fc2',
                '#8c91c3',
                '#8c92c4',
                '#8c94c5',
                '#8c96c6',
                '#8c97c6',
                '#8d98c7',
                '#8e9ac8',
                '#8e9bc8',
                '#8f9dc9',
                '#909eca',
                '#909fcb',
                '#91a1cb',
                '#92a2cc',
                '#92a4cd',
                '#93a5ce',
                '#94a6ce',
                '#94a8cf',
                '#95a9d0',
                '#96abd1',
                '#96acd1',
                '#97add2',
                '#98afd3',
                '#98b0d4',
                '#99b2d4',
                '#9ab3d5',
                '#9ab4d6',
                '#9bb6d7',
                '#9cb7d7',
                '#9cb9d8',
                '#9dbad9',
                '#9ebcda',
                '#9fbcda',
                '#a0bdda',
                '#a1bedb',
                '#a2bfdb',
                '#a4c0dc',
                '#a5c1dc',
                '#a6c1dd',
                '#a7c2dd',
                '#a9c3de',
                '#aac4de',
                '#abc5de',
                '#acc6df',
                '#adc7df',
                '#afc7e0',
                '#b0c8e0',
                '#b1c9e1',
                '#b2cae1',
                '#b4cbe2',
                '#b5cce2',
                '#b6cde2',
                '#b7cde3',
                '#b8cee3',
                '#bacfe4',
                '#bbd0e4',
                '#bcd1e5',
                '#bdd2e5',
                '#bfd3e6',
                '#c0d3e6',
                '#c1d4e7',
                '#c2d5e7',
                '#c3d6e8',
                '#c5d7e8',
                '#c6d8e9',
                '#c7d9e9',
                '#c8daea',
                '#cadbea',
                '#cbdceb',
                '#ccddeb',
                '#cddeec',
                '#cedfec',
                '#d0dfed',
                '#d1e0ed',
                '#d2e1ee',
                '#d3e2ee',
                '#d5e3ef',
                '#d6e4ef',
                '#d7e5f0',
                '#d8e6f0',
                '#d9e7f1',
                '#dbe8f1',
                '#dce9f2',
                '#ddeaf2',
                '#deebf3',
                '#e0ecf4',
                '#e0ecf4',
                '#e1edf4',
                '#e2edf5',
                '#e3eef5',
                '#e4eef5',
                '#e5eff6',
                '#e5f0f6',
                '#e6f0f6',
                '#e7f1f7',
                '#e8f1f7',
                '#e9f2f7',
                '#eaf3f8',
                '#ebf3f8',
                '#ebf4f8',
                '#ecf4f9',
                '#edf5f9',
                '#eef6f9',
                '#eff6fa',
                '#f0f7fa',
                '#f1f7fa',
                '#f1f8fb',
                '#f2f9fb',
                '#f3f9fb',
                '#f4fafc',
                '#f5fafc',
                '#f6fbfc',
                '#f7fcfd']

moxxi = ["#371e24",
        "#2d258c",
        "#ae394a",
        "#d09fad",
        "#f4eaec"]
moxxi256 = ['#371e24',
        '#361e25',
        '#361e27',
        '#361e28',
        '#361e2a',
        '#361e2c',
        '#361e2d',
        '#351e2f',
        '#351e31',
        '#351f32',
        '#351f34',
        '#351f36',
        '#351f37',
        '#341f39',
        '#341f3b',
        '#341f3c',
        '#341f3e',
        '#341f40',
        '#342041',
        '#332043',
        '#332045',
        '#332046',
        '#332048',
        '#332049',
        '#33204b',
        '#33204d',
        '#32204e',
        '#322150',
        '#322152',
        '#322153',
        '#322155',
        '#322157',
        '#312158',
        '#31215a',
        '#31215c',
        '#31215d',
        '#31225f',
        '#312261',
        '#302262',
        '#302264',
        '#302266',
        '#302267',
        '#302269',
        '#30226a',
        '#30226c',
        '#2f236e',
        '#2f236f',
        '#2f2371',
        '#2f2373',
        '#2f2374',
        '#2f2376',
        '#2e2378',
        '#2e2379',
        '#2e237b',
        '#2e247d',
        '#2e247e',
        '#2e2480',
        '#2d2482',
        '#2d2483',
        '#2d2485',
        '#2d2487',
        '#2d2488',
        '#2d248a',
        '#2d258c',
        '#2f258a',
        '#312589',
        '#332588',
        '#352687',
        '#372686',
        '#392685',
        '#3b2784',
        '#3d2783',
        '#3f2782',
        '#412881',
        '#432880',
        '#45287f',
        '#47297e',
        '#49297d',
        '#4b297c',
        '#4d2a7b',
        '#4f2a7a',
        '#512a79',
        '#532b78',
        '#552b77',
        '#582b76',
        '#5a2b74',
        '#5c2c73',
        '#5e2c72',
        '#602c71',
        '#622d70',
        '#642d6f',
        '#662d6e',
        '#682e6d',
        '#6a2e6c',
        '#6c2e6b',
        '#6e2f6a',
        '#702f69',
        '#722f68',
        '#743067',
        '#763066',
        '#783065',
        '#7a3164',
        '#7c3163',
        '#7e3162',
        '#803261',
        '#833260',
        '#85325e',
        '#87325d',
        '#89335c',
        '#8b335b',
        '#8d335a',
        '#8f3459',
        '#913458',
        '#933457',
        '#953556',
        '#973555',
        '#993554',
        '#9b3653',
        '#9d3652',
        '#9f3651',
        '#a13750',
        '#a3374f',
        '#a5374e',
        '#a7384d',
        '#a9384c',
        '#ab384b',
        '#ae394a',
        '#ae3a4b',
        '#af3c4d',
        '#af3d4e',
        '#b03f50',
        '#b04151',
        '#b14253',
        '#b14455',
        '#b24556',
        '#b24758',
        '#b34959',
        '#b34a5b',
        '#b44c5c',
        '#b54e5e',
        '#b54f60',
        '#b65161',
        '#b65263',
        '#b75464',
        '#b75666',
        '#b85767',
        '#b85969',
        '#b95b6b',
        '#b95c6c',
        '#ba5e6e',
        '#ba5f6f',
        '#bb6171',
        '#bc6372',
        '#bc6474',
        '#bd6676',
        '#bd6777',
        '#be6979',
        '#be6b7a',
        '#bf6c7c',
        '#bf6e7d',
        '#c0707f',
        '#c07181',
        '#c17382',
        '#c17484',
        '#c27685',
        '#c37887',
        '#c37988',
        '#c47b8a',
        '#c47d8c',
        '#c57e8d',
        '#c5808f',
        '#c68190',
        '#c68392',
        '#c78593',
        '#c78695',
        '#c88897',
        '#c88998',
        '#c98b9a',
        '#ca8d9b',
        '#ca8e9d',
        '#cb909e',
        '#cb92a0',
        '#cc93a2',
        '#cc95a3',
        '#cd96a5',
        '#cd98a6',
        '#ce9aa8',
        '#ce9ba9',
        '#cf9dab',
        '#d09fad',
        '#d0a0ae',
        '#d1a1af',
        '#d1a2b0',
        '#d2a3b1',
        '#d2a4b2',
        '#d3a6b3',
        '#d4a7b4',
        '#d4a8b5',
        '#d5a9b6',
        '#d5aab7',
        '#d6acb8',
        '#d6adb9',
        '#d7aeba',
        '#d8afbb',
        '#d8b0bc',
        '#d9b2bd',
        '#d9b3be',
        '#dab4bf',
        '#dab5c0',
        '#dbb6c1',
        '#dcb8c2',
        '#dcb9c3',
        '#ddbac4',
        '#ddbbc5',
        '#debcc6',
        '#debdc7',
        '#dfbfc8',
        '#e0c0c9',
        '#e0c1ca',
        '#e1c2cb',
        '#e1c3cc',
        '#e2c5cd',
        '#e2c6ce',
        '#e3c7cf',
        '#e4c8d0',
        '#e4c9d1',
        '#e5cbd2',
        '#e5ccd3',
        '#e6cdd4',
        '#e6ced5',
        '#e7cfd6',
        '#e8d1d7',
        '#e8d2d8',
        '#e9d3d9']

salvia = ['#253237',
        '#cf6a76',
        '#5d61bb',
        '#9db0db']
salvia256 = ['#192326',
 '#1a2427',
 '#1b2528',
 '#1c2629',
 '#1c272a',
 '#1d282c',
 '#1e292d',
 '#1f2a2e',
 '#1f2b2f',
 '#202c30',
 '#212d31',
 '#222e32',
 '#222f33',
 '#233034',
 '#243135',
 '#253237',
 '#263239',
 '#27333c',
 '#28343e',
 '#293541',
 '#2a3644',
 '#2b3746',
 '#2c3849',
 '#2d394c',
 '#2f3a4e',
 '#303b51',
 '#313c54',
 '#323d56',
 '#333e59',
 '#343f5b',
 '#35405e',
 '#364161',
 '#384163',
 '#394266',
 '#3a4369',
 '#3b446b',
 '#3c456e',
 '#3d4671',
 '#3e4773',
 '#3f4876',
 '#414979',
 '#424a7b',
 '#434b7e',
 '#444c80',
 '#454d83',
 '#464e86',
 '#474f88',
 '#48508b',
 '#49518e',
 '#4b5190',
 '#4c5293',
 '#4d5396',
 '#4e5498',
 '#4f559b',
 '#50569d',
 '#5157a0',
 '#5258a3',
 '#5459a5',
 '#555aa8',
 '#565bab',
 '#575cad',
 '#585db0',
 '#595eb3',
 '#5a5fb5',
 '#5b60b8',
 '#5d61bb',
 '#5f61b9',
 '#6161b8',
 '#6361b6',
 '#6661b5',
 '#6861b4',
 '#6a62b2',
 '#6c62b1',
 '#6f62af',
 '#7162ae',
 '#7362ad',
 '#7662ab',
 '#7863aa',
 '#7a63a9',
 '#7c63a7',
 '#7f63a6',
 '#8163a4',
 '#8364a3',
 '#8664a2',
 '#8864a0',
 '#8a649f',
 '#8c649e',
 '#8f649c',
 '#91659b',
 '#936599',
 '#966598',
 '#986597',
 '#9a6595',
 '#9c6694',
 '#9f6692',
 '#a16691',
 '#a36690',
 '#a5668e',
 '#a8668d',
 '#aa678c',
 '#ac678a',
 '#af6789',
 '#b16787',
 '#b36786',
 '#b56885',
 '#b86883',
 '#ba6882',
 '#bc6881',
 '#bf687f',
 '#c1687e',
 '#c3697c',
 '#c5697b',
 '#c8697a',
 '#ca6978',
 '#cc6977',
 '#cf6a76',
 '#ce6b78',
 '#cd6c7a',
 '#cc6e7c',
 '#cb6f7e',
 '#ca7180',
 '#c97282',
 '#c87384',
 '#c77586',
 '#c67688',
 '#c5788a',
 '#c4798c',
 '#c37a8e',
 '#c27c90',
 '#c17d92',
 '#c07f94',
 '#bf8096',
 '#be8198',
 '#bd839a',
 '#bc849c',
 '#bb869e',
 '#ba87a0',
 '#b988a2',
 '#b88aa4',
 '#b78ba6',
 '#b68da8',
 '#b58eaa',
 '#b48fac',
 '#b391ae',
 '#b292b0',
 '#b194b2',
 '#b095b4',
 '#af96b6',
 '#ae98b8',
 '#ad99ba',
 '#ac9bbc',
 '#ab9cbe',
 '#aa9dc0',
 '#a99fc2',
 '#a8a0c4',
 '#a7a2c6',
 '#a6a3c8',
 '#a5a4ca',
 '#a4a6cc',
 '#a3a7ce',
 '#a2a9d0',
 '#a1aad2',
 '#a0abd4',
 '#9fadd6',
 '#9eaed8',
 '#9db0db',
 '#9eb1db',
 '#a0b3dc',
 '#a2b4dd',
 '#a4b6dd',
 '#a6b7de',
 '#a8b9df',
 '#aabbe0',
 '#acbce0',
 '#aebee1',
 '#b0bfe2',
 '#b2c1e2',
 '#b4c2e3',
 '#b6c4e4',
 '#b8c6e5',
 '#bac7e5']

warble = ["#090E1C",
          "#1F2A61",
          "#345AB1",
          "#485DB1",
          "#4C74C0",
          "#5287C8",
          "#6B9BD9",
          "#86B0DD",
          "#AFCCF1",
          "#BDDAFA"]
warble256 =['#090e1c',
 '#090f1e',
 '#0a1021',
 '#0b1123',
 '#0c1226',
 '#0d1328',
 '#0d142b',
 '#0e152d',
 '#0f1630',
 '#101733',
 '#111835',
 '#111938',
 '#121a3a',
 '#131b3d',
 '#141c3f',
 '#151d42',
 '#161e44',
 '#161f47',
 '#17204a',
 '#18214c',
 '#19224f',
 '#1a2351',
 '#1a2454',
 '#1b2556',
 '#1c2659',
 '#1d275b',
 '#1e285e',
 '#1f2a61',
 '#1f2b63',
 '#202d66',
 '#212f69',
 '#22316c',
 '#22326f',
 '#233472',
 '#243675',
 '#253878',
 '#263a7b',
 '#263b7e',
 '#273d81',
 '#283f84',
 '#294187',
 '#29428a',
 '#2a448d',
 '#2b4690',
 '#2c4893',
 '#2d4a96',
 '#2d4b99',
 '#2e4d9c',
 '#2f4f9f',
 '#3051a2',
 '#3052a5',
 '#3154a8',
 '#3256ab',
 '#3358ae',
 '#345ab1',
 '#345ab1',
 '#355ab1',
 '#365ab1',
 '#365ab1',
 '#375ab1',
 '#385ab1',
 '#395ab1',
 '#395ab1',
 '#3a5bb1',
 '#3b5bb1',
 '#3c5bb1',
 '#3c5bb1',
 '#3d5bb1',
 '#3e5bb1',
 '#3f5bb1',
 '#3f5bb1',
 '#405bb1',
 '#415cb1',
 '#425cb1',
 '#425cb1',
 '#435cb1',
 '#445cb1',
 '#455cb1',
 '#455cb1',
 '#465cb1',
 '#475cb1',
 '#485db1',
 '#485db1',
 '#485eb2',
 '#485fb2',
 '#4860b3',
 '#4861b3',
 '#4862b4',
 '#4962b4',
 '#4963b5',
 '#4964b6',
 '#4965b6',
 '#4966b7',
 '#4967b7',
 '#4968b8',
 '#4a68b8',
 '#4a69b9',
 '#4a6ab9',
 '#4a6bba',
 '#4a6cbb',
 '#4a6dbb',
 '#4a6ebc',
 '#4b6ebc',
 '#4b6fbd',
 '#4b70bd',
 '#4b71be',
 '#4b72be',
 '#4b73bf',
 '#4c74c0',
 '#4c74c0',
 '#4c75c0',
 '#4c76c0',
 '#4c76c1',
 '#4d77c1',
 '#4d78c1',
 '#4d78c2',
 '#4d79c2',
 '#4e7ac2',
 '#4e7bc2',
 '#4e7bc3',
 '#4e7cc3',
 '#4e7dc3',
 '#4f7dc4',
 '#4f7ec4',
 '#4f7fc4',
 '#4f7fc5',
 '#5080c5',
 '#5081c5',
 '#5082c5',
 '#5082c6',
 '#5083c6',
 '#5184c6',
 '#5184c7',
 '#5185c7',
 '#5186c7',
 '#5287c8',
 '#5287c8',
 '#5388c9',
 '#5489c9',
 '#5589ca',
 '#568acb',
 '#578bcb',
 '#588ccc',
 '#598ccd',
 '#5a8dcd',
 '#5b8ece',
 '#5c8fce',
 '#5d8fcf',
 '#5e90d0',
 '#5e91d0',
 '#5f92d1',
 '#6092d2',
 '#6193d2',
 '#6294d3',
 '#6395d3',
 '#6495d4',
 '#6596d5',
 '#6697d5',
 '#6798d6',
 '#6898d7',
 '#6999d7',
 '#6a9ad8',
 '#6b9bd9',
 '#6c9bd9',
 '#6d9cd9',
 '#6e9dd9',
 '#6f9ed9',
 '#709ed9',
 '#719fd9',
 '#72a0da',
 '#73a1da',
 '#74a2da',
 '#75a2da',
 '#76a3da',
 '#77a4da',
 '#78a5da',
 '#79a5db',
 '#7aa6db',
 '#7ba7db',
 '#7ca8db',
 '#7da9db',
 '#7ea9db',
 '#7faadb',
 '#80abdc',
 '#81acdc',
 '#82acdc',
 '#83addc',
 '#84aedc',
 '#85afdc',
 '#86b0dd',
 '#87b1dd',
 '#89b2de',
 '#8ab3df',
 '#8cb4df',
 '#8db5e0',
 '#8fb6e1',
 '#90b7e2',
 '#92b8e2',
 '#93b9e3',
 '#95bae4',
 '#96bbe5',
 '#98bce5',
 '#99bde6',
 '#9bbee7',
 '#9cbfe8',
 '#9ec0e8',
 '#9fc1e9',
 '#a1c2ea',
 '#a2c3eb',
 '#a4c4eb',
 '#a5c5ec',
 '#a7c6ed',
 '#a8c7ee',
 '#aac8ee',
 '#abc9ef',
 '#adcaf0',
 '#afccf1',
 '#afccf1',
 '#b0cdf1',
 '#b0cdf2',
 '#b1cef2',
 '#b1cef2',
 '#b2cff3',
 '#b2cff3',
 '#b3d0f3',
 '#b3d0f4',
 '#b4d1f4',
 '#b4d1f4',
 '#b5d2f5',
 '#b5d2f5',
 '#b6d3f5',
 '#b6d3f6',
 '#b7d4f6',
 '#b7d4f6',
 '#b8d5f7',
 '#b8d5f7',
 '#b9d6f7',
 '#b9d6f8',
 '#bad7f8',
 '#bad7f8',
 '#bbd8f9',
 '#bbd8f9',
 '#bcd9f9',
 '#bddafa']

waitomo = ['#12144a',
           '#1e286c',
           '#2b3d8e',
            '#325b96',
            '#38799b',
            '#5e96ab',
            '#8db1bf']
waitomo256 = ['#12144a',
 '#12144b',
 '#12154c',
 '#13164d',
 '#13164e',
 '#14174f',
 '#141850',
 '#151852',
 '#151953',
 '#151a54',
 '#161a55',
 '#161b56',
 '#171c57',
 '#171d58',
 '#181d5a',
 '#181e5b',
 '#181f5c',
 '#191f5d',
 '#19205e',
 '#1a215f',
 '#1a2160',
 '#1b2262',
 '#1b2363',
 '#1b2464',
 '#1c2465',
 '#1c2566',
 '#1d2667',
 '#1d2668',
 '#1e276a',
 '#1e286b',
 '#1e286c',
 '#1f296d',
 '#1f2a6e',
 '#202b6f',
 '#202b70',
 '#212c72',
 '#212d73',
 '#212d74',
 '#222e75',
 '#222f76',
 '#232f77',
 '#233078',
 '#24317a',
 '#24327b',
 '#24327c',
 '#25337d',
 '#25347e',
 '#26347f',
 '#263580',
 '#273682',
 '#273683',
 '#273784',
 '#283885',
 '#283986',
 '#293987',
 '#293a88',
 '#2a3b8a',
 '#2a3b8b',
 '#2a3c8c',
 '#2b3d8d',
 '#2b3d8e',
 '#2c3e8f',
 '#2c3f90',
 '#2d4092',
 '#2d4192',
 '#2d4292',
 '#2d4392',
 '#2d4492',
 '#2e4592',
 '#2e4692',
 '#2e4793',
 '#2e4893',
 '#2e4993',
 '#2f4a93',
 '#2f4b93',
 '#2f4c93',
 '#2f4d94',
 '#2f4e94',
 '#304f94',
 '#305094',
 '#305194',
 '#305294',
 '#305395',
 '#315495',
 '#315595',
 '#315695',
 '#315795',
 '#315895',
 '#325995',
 '#325a96',
 '#325b96',
 '#325c96',
 '#325d96',
 '#335e96',
 '#335f96',
 '#336097',
 '#336197',
 '#346297',
 '#346397',
 '#346497',
 '#346597',
 '#346698',
 '#356798',
 '#356898',
 '#356998',
 '#356a98',
 '#356b98',
 '#366c98',
 '#366d99',
 '#366e99',
 '#366f99',
 '#367099',
 '#377199',
 '#377299',
 '#37739a',
 '#37749a',
 '#37759a',
 '#38769a',
 '#38779a',
 '#38789a',
 '#38799b',
 '#387a9b',
 '#397b9b',
 '#397c9b',
 '#397d9b',
 '#397e9b',
 '#3a809c',
 '#3b809c',
 '#3d819d',
 '#3e829d',
 '#40839e',
 '#41849f',
 '#43859f',
 '#4486a0',
 '#4687a1',
 '#4788a1',
 '#4989a2',
 '#4a8aa3',
 '#4c8ba3',
 '#4e8ba4',
 '#4f8ca5',
 '#518da5',
 '#528ea6',
 '#548fa7',
 '#5590a7',
 '#5791a8',
 '#5892a9',
 '#5a93a9',
 '#5b94aa',
 '#5d95aa',
 '#5e96ab',
 '#6097ac',
 '#6297ac',
 '#6398ad',
 '#6599ae',
 '#669aae',
 '#689baf',
 '#699cb0',
 '#6b9db0',
 '#6c9eb1',
 '#6e9fb2',
 '#6fa0b2',
 '#71a1b3',
 '#72a2b4',
 '#74a2b4',
 '#76a3b5',
 '#77a4b6',
 '#79a5b6',
 '#7aa6b7',
 '#7ca7b7',
 '#7da8b8',
 '#7fa9b9',
 '#80aab9',
 '#82abba',
 '#83acbb',
 '#85adbb',
 '#86aebc',
 '#88aebd',
 '#8aafbd',
 '#8bb0be',
 '#8db1bf',
 '#8eb2bf',
 '#90b3c0',
 '#91b4c1',
 '#93b5c1',
 '#94b6c2',
 '#96b7c3',
 '#97b8c3',
 '#99b9c4',
 '#9bbac5',
 '#9bbac5',
 '#9bbac6',
 '#9cbbc7',
 '#9cbbc7',
 '#9cbcc8',
 '#9dbcc9',
 '#9dbdc9',
 '#9dbdca',
 '#9ebecb',
 '#9ebecb',
 '#9ebfcc',
 '#9fbfcd',
 '#9fbfcd',
 '#9fc0ce',
 '#a0c0cf',
 '#a0c1cf',
 '#a0c1d0',
 '#a1c2d1',
 '#a1c2d1',
 '#a1c3d2',
 '#a2c3d3',
 '#a2c4d3',
 '#a2c4d4',
 '#a3c5d5',
 '#a3c5d5',
 '#a3c5d6',
 '#a4c6d7',
 '#a4c6d7',
 '#a4c7d8',
 '#a5c7d9',
 '#a5c8d9',
 '#a5c8da',
 '#a6c9db',
 '#a6c9db',
 '#a6cadc',
 '#a7cadd',
 '#a7cbdd',
 '#a7cbde',
 '#a8cbdf',
 '#a8ccdf',
 '#a8cce0',
 '#a9cde1',
 '#a9cde1',
 '#a9cee2',
 '#aacee3',
 '#aacfe3',
 '#aacfe4',
 '#abd0e5',
 '#abd0e5',
 '#abd1e6',
 '#acd1e7',
 '#acd1e7',
 '#acd2e8',
 '#add2e9',
 '#add3e9',
 '#add3ea',
 '#aed4eb',
 '#aed4eb',
 '#aed5ec',
 '#afd5ed',
 '#afd6ed',
 '#afd6ee',
 '#b0d7ef']

vylette = ['#300546',
            '#3c1062',
            '#481b7e',
            '#55279b',
            '#692f99',
            '#7d3898',
            '#924197',
            '#b06eb5',
            '#ce9bd4',
             '#edc8f3']
vylette256 = ['#300546',
 '#300547',
 '#300548',
 '#310649',
 '#31064a',
 '#32074b',
 '#32074c',
 '#33074d',
 '#33084e',
 '#34084f',
 '#340950',
 '#340951',
 '#350952',
 '#350a53',
 '#360a54',
 '#360b55',
 '#370b56',
 '#370b57',
 '#380c58',
 '#380c59',
 '#380d5a',
 '#390d5b',
 '#390d5c',
 '#3a0e5d',
 '#3a0e5e',
 '#3b0f5f',
 '#3b0f60',
 '#3c1062',
 '#3c1063',
 '#3c1064',
 '#3d1165',
 '#3d1166',
 '#3e1267',
 '#3e1268',
 '#3f1269',
 '#3f136a',
 '#40136b',
 '#40146c',
 '#40146d',
 '#41146e',
 '#41156f',
 '#421570',
 '#421671',
 '#431672',
 '#431673',
 '#441774',
 '#441775',
 '#441876',
 '#451877',
 '#451878',
 '#461979',
 '#46197a',
 '#471a7b',
 '#471a7c',
 '#481b7e',
 '#481b7f',
 '#481b80',
 '#491c81',
 '#491c82',
 '#4a1d83',
 '#4a1d84',
 '#4b1e85',
 '#4b1e86',
 '#4c1f87',
 '#4c1f88',
 '#4d1f89',
 '#4d208a',
 '#4e208b',
 '#4e218d',
 '#4f218e',
 '#4f228f',
 '#502290',
 '#502391',
 '#512392',
 '#512393',
 '#522494',
 '#522495',
 '#532596',
 '#532597',
 '#542698',
 '#542699',
 '#55279b',
 '#55279a',
 '#56279a',
 '#57279a',
 '#57289a',
 '#58289a',
 '#59289a',
 '#5a299a',
 '#5a299a',
 '#5b299a',
 '#5c299a',
 '#5d2a9a',
 '#5d2a9a',
 '#5e2a9a',
 '#5f2b99',
 '#602b99',
 '#602b99',
 '#612c99',
 '#622c99',
 '#632c99',
 '#632c99',
 '#642d99',
 '#652d99',
 '#662d99',
 '#662e99',
 '#672e99',
 '#682e99',
 '#692f99',
 '#692f98',
 '#6a2f98',
 '#6b3098',
 '#6b3098',
 '#6c3098',
 '#6d3198',
 '#6e3198',
 '#6e3198',
 '#6f3298',
 '#703298',
 '#713298',
 '#713398',
 '#723398',
 '#733398',
 '#743498',
 '#743498',
 '#753498',
 '#763598',
 '#773598',
 '#773598',
 '#783698',
 '#793698',
 '#7a3698',
 '#7a3798',
 '#7b3798',
 '#7c3798',
 '#7d3898',
 '#7d3897',
 '#7e3897',
 '#7f3997',
 '#803997',
 '#803997',
 '#813a97',
 '#823a97',
 '#833a97',
 '#843b97',
 '#843b97',
 '#853b97',
 '#863c97',
 '#873c97',
 '#873c97',
 '#883d97',
 '#893d97',
 '#8a3d97',
 '#8b3e97',
 '#8b3e97',
 '#8c3e97',
 '#8d3f97',
 '#8e3f97',
 '#8e3f97',
 '#8f4097',
 '#904097',
 '#914097',
 '#924197',
 '#934298',
 '#944499',
 '#95469a',
 '#96479b',
 '#97499c',
 '#984b9d',
 '#994c9e',
 '#9a4e9f',
 '#9c50a1',
 '#9d51a2',
 '#9e53a3',
 '#9f55a4',
 '#a056a5',
 '#a158a6',
 '#a25aa7',
 '#a35ba8',
 '#a45da9',
 '#a65fab',
 '#a760ac',
 '#a862ad',
 '#a964ae',
 '#aa65af',
 '#ab67b0',
 '#ac69b1',
 '#ad6ab2',
 '#ae6cb3',
 '#b06eb5',
 '#b16fb6',
 '#b271b7',
 '#b373b8',
 '#b474b9',
 '#b576ba',
 '#b678bb',
 '#b779bd',
 '#b87bbe',
 '#ba7dbf',
 '#bb7ec0',
 '#bc80c1',
 '#bd82c2',
 '#be83c3',
 '#bf85c5',
 '#c087c6',
 '#c188c7',
 '#c28ac8',
 '#c48cc9',
 '#c58dca',
 '#c68fcb',
 '#c791cd',
 '#c892ce',
 '#c994cf',
 '#ca96d0',
 '#cb97d1',
 '#cc99d2',
 '#ce9bd4',
 '#cf9cd5',
 '#d09ed6',
 '#d1a0d7',
 '#d2a1d8',
 '#d3a3d9',
 '#d4a5da',
 '#d6a6dc',
 '#d7a8dd',
 '#d8aade',
 '#d9abdf',
 '#daade0',
 '#dbafe1',
 '#dcb0e2',
 '#deb2e4',
 '#dfb4e5',
 '#e0b5e6',
 '#e1b7e7',
 '#e2b9e8',
 '#e3bae9',
 '#e4bcea',
 '#e6beec',
 '#e7bfed',
 '#e8c1ee',
 '#e9c3ef',
 '#eac4f0',
 '#ebc6f1',
 '#edc8f3']

pom = ["#13080A",
        "#580D11",
        "#B33650",
        "#E05666",
        "#edb1a3"]
pom256 = ['#13080a', '#14080a', '#15080a', '#16080a',
'#17080a', '#18080a', '#19080a', '#1a080a', '#1b080a',
'#1c080b', '#1d080b', '#1f080b', '#20080b', '#21090b',
'#22090b', '#23090b', '#24090b', '#25090b', '#26090c',
'#27090c', '#28090c', '#2a090c', '#2b090c', '#2c090c',
'#2d090c', '#2e090c', '#2f0a0c', '#300a0d', '#310a0d',
'#320a0d', '#330a0d', '#340a0d', '#360a0d', '#370a0d',
'#380a0d', '#390a0d', '#3a0a0e', '#3b0a0e', '#3c0b0e',
'#3d0b0e', '#3e0b0e', '#3f0b0e', '#410b0e', '#420b0e',
'#430b0e', '#440b0f', '#450b0f', '#460b0f', '#470b0f',
'#480b0f', '#490b0f', '#4a0c0f', '#4b0c0f', '#4d0c0f',
'#4e0c10', '#4f0c10', '#500c10', '#510c10', '#520c10',
'#530c10', '#540c10', '#550c10', '#560c10', '#580d11',
'#590d12', '#5a0e13', '#5c0e14', '#5d0f15', '#5f1016',
'#601017', '#621118', '#631219', '#65121a', '#66131b',
'#67141c', '#69141d', '#6a151e', '#6c161f', '#6d1620',
'#6f1721', '#701822', '#721823', '#731924', '#741a25',
'#761a26', '#771b27', '#791b28', '#7a1c29', '#7c1d2a',
'#7d1d2b', '#7f1e2c', '#801f2d', '#811f2e', '#83202f',
'#842130', '#862131', '#872232', '#892333', '#8a2334',
'#8c2435', '#8d2536', '#8e2537', '#902638', '#912739',
'#93273a', '#94283b', '#96283c', '#97293d', '#992a3e',
'#9a2a3f', '#9b2b40', '#9d2c41', '#9e2c42', '#a02d43',
'#a12e44', '#a32e45', '#a42f46', '#a63047', '#a73048',
'#a83149', '#aa324a', '#ab324b', '#ad334c', '#ae344d',
'#b0344e', '#b1354f', '#b33650', '#b33650', '#b43750',
'#b53751', '#b53851', '#b63851', '#b73952', '#b83952',
'#b83a52', '#b93a53', '#ba3b53', '#ba3b53', '#bb3c54',
'#bc3c54', '#bd3d54', '#bd3d55', '#be3e55', '#bf3e55',
'#bf3f56', '#c03f56', '#c14056', '#c24057', '#c24157',
'#c34158', '#c44258', '#c44258', '#c54359', '#c64359',
'#c74459', '#c7445a', '#c8455a', '#c9455a', '#c9465b',
'#ca465b', '#cb475b', '#cc475c', '#cc485c', '#cd485c',
'#ce495d', '#ce495d', '#cf4a5d', '#d04a5e', '#d14b5e',
'#d14b5f', '#d24c5f', '#d34c5f', '#d34d60', '#d44d60',
'#d54e60', '#d64e61', '#d64f61', '#d74f61', '#d85062',
'#d85062', '#d95162', '#da5163', '#db5263', '#db5263',
'#dc5364', '#dd5364', '#dd5464', '#de5465', '#df5565',
'#e05666', '#e05766', '#e05867', '#e05a68', '#e05b69',
'#e15d6a', '#e15e6b', '#e1606c', '#e1616d', '#e1636e',
'#e2646f', '#e26570', '#e26771', '#e26872', '#e26a73',
'#e36b74', '#e36d75', '#e36e76', '#e37077', '#e37178',
'#e47279', '#e4747a', '#e4757b', '#e4777c', '#e4787d',
'#e57a7e', '#e57b7f', '#e57d80', '#e57e81', '#e57f82',
'#e68183', '#e68284', '#e68484', '#e68585', '#e78786',
'#e78887', '#e78a88', '#e78b89', '#e78c8a', '#e88e8b',
'#e88f8c', '#e8918d', '#e8928e', '#e8948f', '#e99590',
'#e99791', '#e99892', '#e99993', '#e99b94', '#ea9c95',
'#ea9e96', '#ea9f97', '#eaa198', '#eaa299', '#eba49a',
'#eba59b', '#eba69c', '#eba89d', '#eba99e', '#ecab9f',
'#ecaca0', '#ecaea1', '#ecafa2', '#edb1a3']

lava = ['#0a0922',
        '#5c2454',
        '#891f59',
        '#b6284a',
        '#d36047',
        '#df9a75',
        '#f5e8da']
lava256 = ['#0a0922',
 '#0c0923',
 '#0e0a24',
 '#100a25',
 '#120b26',
 '#140c28',
 '#160c29',
 '#180d2a',
 '#1a0e2b',
 '#1c0e2c',
 '#1e0f2e',
 '#20102f',
 '#221030',
 '#241131',
 '#261233',
 '#281234',
 '#2a1335',
 '#2c1436',
 '#2e1437',
 '#301539',
 '#32163a',
 '#34163b',
 '#36173c',
 '#38183e',
 '#3a183f',
 '#3c1940',
 '#3e1a41',
 '#401a42',
 '#421b44',
 '#441c45',
 '#461c46',
 '#481d47',
 '#4a1e49',
 '#4c1e4a',
 '#4e1f4b',
 '#50204c',
 '#52204d',
 '#54214f',
 '#562250',
 '#582251',
 '#5a2352',
 '#5c2454',
 '#5d2354',
 '#5e2354',
 '#5f2354',
 '#602354',
 '#612354',
 '#622354',
 '#632354',
 '#642354',
 '#652255',
 '#662255',
 '#682255',
 '#692255',
 '#6a2255',
 '#6b2255',
 '#6c2255',
 '#6d2255',
 '#6e2156',
 '#6f2156',
 '#702156',
 '#712156',
 '#732156',
 '#742156',
 '#752156',
 '#762156',
 '#772057',
 '#782057',
 '#792057',
 '#7a2057',
 '#7b2057',
 '#7c2057',
 '#7e2057',
 '#7f2057',
 '#801f58',
 '#811f58',
 '#821f58',
 '#831f58',
 '#841f58',
 '#851f58',
 '#861f58',
 '#871f58',
 '#891f59',
 '#8a1f58',
 '#8b1f58',
 '#8c1f57',
 '#8d1f57',
 '#8e2057',
 '#8f2056',
 '#902056',
 '#912056',
 '#922055',
 '#932155',
 '#952154',
 '#962154',
 '#972154',
 '#982253',
 '#992253',
 '#9a2253',
 '#9b2252',
 '#9c2252',
 '#9d2352',
 '#9e2351',
 '#a02351',
 '#a12350',
 '#a22450',
 '#a32450',
 '#a4244f',
 '#a5244f',
 '#a6244f',
 '#a7254e',
 '#a8254e',
 '#a9254e',
 '#ab254d',
 '#ac264d',
 '#ad264c',
 '#ae264c',
 '#af264c',
 '#b0264b',
 '#b1274b',
 '#b2274b',
 '#b3274a',
 '#b4274a',
 '#b6284a',
 '#b62949',
 '#b72a49',
 '#b82c49',
 '#b82d49',
 '#b92e49',
 '#ba3049',
 '#ba3149',
 '#bb3249',
 '#bc3449',
 '#bd3549',
 '#bd3749',
 '#be3849',
 '#bf3949',
 '#bf3b48',
 '#c03c48',
 '#c13d48',
 '#c23f48',
 '#c24048',
 '#c34148',
 '#c44348',
 '#c44448',
 '#c54648',
 '#c64748',
 '#c64848',
 '#c74a48',
 '#c84b48',
 '#c94c48',
 '#c94e47',
 '#ca4f47',
 '#cb5047',
 '#cb5247',
 '#cc5347',
 '#cd5547',
 '#ce5647',
 '#ce5747',
 '#cf5947',
 '#d05a47',
 '#d05b47',
 '#d15d47',
 '#d25e47',
 '#d36047',
 '#d36148',
 '#d36249',
 '#d3644a',
 '#d4654b',
 '#d4674c',
 '#d4684d',
 '#d5694e',
 '#d56b4f',
 '#d56c51',
 '#d56e52',
 '#d66f53',
 '#d67054',
 '#d67255',
 '#d77356',
 '#d77557',
 '#d77658',
 '#d7785a',
 '#d8795b',
 '#d87a5c',
 '#d87c5d',
 '#d97d5e',
 '#d97f5f',
 '#d98060',
 '#da8161',
 '#da8363',
 '#da8464',
 '#da8665',
 '#db8766',
 '#db8967',
 '#db8a68',
 '#dc8b69',
 '#dc8d6a',
 '#dc8e6c',
 '#dc906d',
 '#dd916e',
 '#dd926f',
 '#dd9470',
 '#de9571',
 '#de9772',
 '#de9873',
 '#df9a75',
 '#df9b77',
 '#e09d79',
 '#e09f7c',
 '#e1a17e',
 '#e1a381',
 '#e2a583',
 '#e2a786',
 '#e3a988',
 '#e3ab8b',
 '#e4ad8d',
 '#e4ae90',
 '#e5b092',
 '#e5b295',
 '#e6b497',
 '#e7b699',
 '#e7b89c',
 '#e8ba9e',
 '#e8bca1',
 '#e9bea3',
 '#e9c0a6',
 '#eac1a8',
 '#eac3ab',
 '#ebc5ad',
 '#ebc7b0',
 '#ecc9b2',
 '#eccbb5',
 '#edcdb7',
 '#eecfb9',
 '#eed1bc',
 '#efd3be',
 '#efd4c1',
 '#f0d6c3',
 '#f0d8c6',
 '#f1dac8',
 '#f1dccb',
 '#f2decd',
 '#f2e0d0',
 '#f3e2d2',
 '#f3e4d5',
 '#f4e6d7',
 '#f5e8da']

pumpkin = ["#2D1611",
           "#5E1615",
           "#881A12",
           "#B4281F",
              "#CB4324",
            "#C65425",
                "#CF6630",
                   "#D06830",
                   "#D38B3A",
                   "#D3AB3A",
                   "#DFBB44",
                   "#EAD9A3",
                   "#EDEBE0"]
pumpkin256 = ['#2d1611',
 '#2f1611',
 '#311611',
 '#341611',
 '#361611',
 '#391612',
 '#3b1612',
 '#3e1612',
 '#401612',
 '#431612',
 '#451613',
 '#471613',
 '#4a1613',
 '#4c1613',
 '#4f1613',
 '#511614',
 '#541614',
 '#561614',
 '#591614',
 '#5b1614',
 '#5e1615',
 '#601614',
 '#621614',
 '#641614',
 '#661614',
 '#681714',
 '#6a1714',
 '#6c1713',
 '#6e1713',
 '#701713',
 '#731813',
 '#751813',
 '#771813',
 '#791813',
 '#7b1812',
 '#7d1912',
 '#7f1912',
 '#811912',
 '#831912',
 '#851912',
 '#881a12',
 '#8a1a12',
 '#8c1b13',
 '#8e1c13',
 '#901c14',
 '#931d15',
 '#951e15',
 '#971e16',
 '#991f17',
 '#9b2017',
 '#9e2118',
 '#a02119',
 '#a22219',
 '#a4231a',
 '#a6231b',
 '#a9241b',
 '#ab251c',
 '#ad251d',
 '#af261d',
 '#b1271e',
 '#b4281f',
 '#b5291f',
 '#b62a1f',
 '#b72c1f',
 '#b82d20',
 '#b92e20',
 '#ba3020',
 '#bc3120',
 '#bd3221',
 '#be3421',
 '#bf3521',
 '#c03621',
 '#c13822',
 '#c23922',
 '#c43a22',
 '#c53c22',
 '#c63d23',
 '#c73e23',
 '#c84023',
 '#c94123',
 '#cb4324',
 '#ca4324',
 '#ca4424',
 '#ca4524',
 '#ca4624',
 '#c94724',
 '#c94824',
 '#c94824',
 '#c94924',
 '#c84a24',
 '#c84b24',
 '#c84c24',
 '#c84d24',
 '#c74e24',
 '#c74e24',
 '#c74f24',
 '#c75024',
 '#c65124',
 '#c65224',
 '#c65324',
 '#c65425',
 '#c65425',
 '#c65526',
 '#c75626',
 '#c75727',
 '#c85827',
 '#c85928',
 '#c95a28',
 '#c95b29',
 '#ca5c29',
 '#ca5d2a',
 '#ca5d2b',
 '#cb5e2b',
 '#cb5f2c',
 '#cc602c',
 '#cc612d',
 '#cd622d',
 '#cd632e',
 '#ce642e',
 '#ce652f',
 '#cf6630',
 '#cf6630',
 '#cf6630',
 '#cf6630',
 '#cf6630',
 '#cf6630',
 '#cf6630',
 '#cf6630',
 '#cf6630',
 '#cf6630',
 '#cf6730',
 '#cf6730',
 '#cf6730',
 '#cf6730',
 '#cf6730',
 '#cf6730',
 '#cf6730',
 '#cf6730',
 '#cf6730',
 '#cf6730',
 '#d06830',
 '#d06930',
 '#d06b31',
 '#d06d31',
 '#d06f32',
 '#d07032',
 '#d07233',
 '#d17433',
 '#d17634',
 '#d17734',
 '#d17935',
 '#d17b35',
 '#d17d36',
 '#d17e36',
 '#d28037',
 '#d28237',
 '#d28438',
 '#d28538',
 '#d28739',
 '#d28939',
 '#d38b3a',
 '#d38c3a',
 '#d38e3a',
 '#d38f3a',
 '#d3913a',
 '#d3933a',
 '#d3943a',
 '#d3963a',
 '#d3973a',
 '#d3993a',
 '#d39b3a',
 '#d39c3a',
 '#d39e3a',
 '#d39f3a',
 '#d3a13a',
 '#d3a33a',
 '#d3a43a',
 '#d3a63a',
 '#d3a73a',
 '#d3a93a',
 '#d3ab3a',
 '#d3ab3a',
 '#d4ac3b',
 '#d4ad3b',
 '#d5ae3c',
 '#d6af3c',
 '#d6af3d',
 '#d7b03d',
 '#d7b13e',
 '#d8b23e',
 '#d9b33f',
 '#d9b33f',
 '#dab440',
 '#dab540',
 '#dbb641',
 '#dcb741',
 '#dcb742',
 '#ddb842',
 '#ddb943',
 '#deba43',
 '#dfbb44',
 '#dfbc48',
 '#e0be4d',
 '#e0bf52',
 '#e1c157',
 '#e1c25b',
 '#e2c460',
 '#e2c565',
 '#e3c76a',
 '#e3c86e',
 '#e4ca73',
 '#e5cb78',
 '#e5cd7d',
 '#e6ce81',
 '#e6d086',
 '#e7d18b',
 '#e7d390',
 '#e8d494',
 '#e8d699',
 '#e9d79e',
 '#ead9a3',
 '#ead9a6',
 '#eadaa9',
 '#eadbac',
 '#eadcaf',
 '#eaddb2',
 '#eadeb5',
 '#ebdfb8',
 '#ebe0bb',
 '#ebe1be',
 '#ebe2c1',
 '#ebe2c4',
 '#ebe3c7',
 '#ebe4ca',
 '#ece5cd',
 '#ece6d0',
 '#ece7d3',
 '#ece8d6',
 '#ece9d9',
 '#eceadc',
 '#edebe0']

pinctada = nacre = ["#1C2A1E",
            "#1C4743",
            "#265A54",
             "#2F6F6A",
             "#378078",
             "#5C9288",
             "#5A8F85",
             "#759E8E",
             "#A7BAA8",
             "#EDEBE0"
             ]
pinctada256 = nacre256 = ['#1c2a1e',
 '#1c2b1f',
 '#1c2c20',
 '#1c2d22',
 '#1c2e23',
 '#1c2f24',
 '#1c3026',
 '#1c3127',
 '#1c3228',
 '#1c332a',
 '#1c342b',
 '#1c352d',
 '#1c362e',
 '#1c372f',
 '#1c3931',
 '#1c3a32',
 '#1c3b33',
 '#1c3c35',
 '#1c3d36',
 '#1c3e38',
 '#1c3f39',
 '#1c403a',
 '#1c413c',
 '#1c423d',
 '#1c433e',
 '#1c4440',
 '#1c4541',
 '#1c4743',
 '#1c4743',
 '#1c4844',
 '#1d4944',
 '#1d4945',
 '#1d4a46',
 '#1e4b46',
 '#1e4b47',
 '#1e4c48',
 '#1f4d48',
 '#1f4e49',
 '#204e49',
 '#204f4a',
 '#20504b',
 '#21504b',
 '#21514c',
 '#21524d',
 '#22524d',
 '#22534e',
 '#23544e',
 '#23554f',
 '#235550',
 '#245650',
 '#245751',
 '#245752',
 '#255852',
 '#255953',
 '#265a54',
 '#265a54',
 '#265b55',
 '#275c56',
 '#275d57',
 '#275d58',
 '#285e58',
 '#285f59',
 '#28605a',
 '#29615b',
 '#29615c',
 '#29625c',
 '#2a635d',
 '#2a645e',
 '#2a645f',
 '#2b6560',
 '#2b6661',
 '#2b6761',
 '#2c6862',
 '#2c6863',
 '#2c6964',
 '#2d6a65',
 '#2d6b65',
 '#2d6b66',
 '#2e6c67',
 '#2e6d68',
 '#2e6e69',
 '#2f6f6a',
 '#2f6f6a',
 '#2f706b',
 '#2f706b',
 '#30716c',
 '#30726c',
 '#30726d',
 '#31736d',
 '#31746e',
 '#31746e',
 '#31756f',
 '#32756f',
 '#327670',
 '#327770',
 '#337771',
 '#337871',
 '#337972',
 '#347972',
 '#347a73',
 '#347a73',
 '#347b74',
 '#357c74',
 '#357c75',
 '#357d75',
 '#367e76',
 '#367e76',
 '#367f77',
 '#378078',
 '#388078',
 '#398179',
 '#3b8279',
 '#3c827a',
 '#3d837a',
 '#3f847b',
 '#40847c',
 '#41857c',
 '#43867d',
 '#44867d',
 '#46877e',
 '#47887f',
 '#48887f',
 '#4a8980',
 '#4b8a80',
 '#4c8a81',
 '#4e8b82',
 '#4f8c82',
 '#518c83',
 '#528d83',
 '#538e84',
 '#558e85',
 '#568f85',
 '#579086',
 '#599086',
 '#5a9187',
 '#5c9288',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5b9086',
 '#5b9086',
 '#5b9086',
 '#5b9086',
 '#5a9086',
 '#5a9086',
 '#5a9086',
 '#5a9086',
 '#5a9086',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5b8f85',
 '#5c9085',
 '#5d9086',
 '#5e9186',
 '#5f9186',
 '#609287',
 '#619287',
 '#629387',
 '#639488',
 '#649488',
 '#659588',
 '#669589',
 '#679689',
 '#689689',
 '#69978a',
 '#6a978a',
 '#6b988a',
 '#6c998b',
 '#6d998b',
 '#6e9a8b',
 '#6f9a8c',
 '#709b8c',
 '#719b8c',
 '#729c8d',
 '#739c8d',
 '#749d8d',
 '#759e8e',
 '#769f8e',
 '#78a08f',
 '#7aa190',
 '#7ca291',
 '#7ea392',
 '#80a493',
 '#81a594',
 '#83a695',
 '#85a796',
 '#87a897',
 '#89a998',
 '#8baa99',
 '#8dab9a',
 '#8eac9b',
 '#90ad9c',
 '#92ae9d',
 '#94af9e',
 '#96b09f',
 '#98b1a0',
 '#9ab2a1',
 '#9bb3a2',
 '#9db4a3',
 '#9fb5a4',
 '#a1b6a5',
 '#a3b7a6',
 '#a5b8a7',
 '#a7baa8',
 '#a9bbaa',
 '#acbdac',
 '#aebfae',
 '#b1c1b0',
 '#b3c3b2',
 '#b6c4b4',
 '#b9c6b6',
 '#bbc8b8',
 '#becaba',
 '#c0ccbc',
 '#c3cdbe',
 '#c6cfc0',
 '#c8d1c2',
 '#cbd3c5',
 '#cdd5c7',
 '#d0d7c9',
 '#d3d8cb',
 '#d5dacd',
 '#d8dccf',
 '#daded1',
 '#dde0d3',
 '#e0e1d5',
 '#e2e3d7',
 '#e5e5d9',
 '#e7e7db',
 '#eae9dd',
 '#edebe0']

crest = ['#000831',
        '#0b1738',
        '#172740',
        '#233647',
        '#2f464f',
        '#2d6366',
        '#2c817e',
        '#2a9f95',
        '#29bdad',
         '#48c7b8',
         '#67d1c4',
         '#86dbcf']
crest256 = ['#000831',
 '#000831',
 '#010931',
 '#010a32',
 '#020a32',
 '#020b32',
 '#030c33',
 '#030d33',
 '#040d33',
 '#050e34',
 '#050f34',
 '#061034',
 '#061035',
 '#071135',
 '#071236',
 '#081336',
 '#081336',
 '#091437',
 '#0a1537',
 '#0a1637',
 '#0b1638',
 '#0b1738',
 '#0c1838',
 '#0c1839',
 '#0d1939',
 '#0d1a39',
 '#0e1b3a',
 '#0f1b3a',
 '#0f1c3b',
 '#101d3b',
 '#101e3b',
 '#111e3c',
 '#111f3c',
 '#12203c',
 '#13213d',
 '#13213d',
 '#14223d',
 '#14233e',
 '#15243e',
 '#15243e',
 '#16253f',
 '#16263f',
 '#172740',
 '#182740',
 '#182840',
 '#192941',
 '#192941',
 '#1a2a41',
 '#1a2b42',
 '#1b2c42',
 '#1b2c42',
 '#1c2d43',
 '#1d2e43',
 '#1d2f43',
 '#1e2f44',
 '#1e3044',
 '#1f3145',
 '#1f3245',
 '#203245',
 '#213346',
 '#213446',
 '#223546',
 '#223547',
 '#233647',
 '#233747',
 '#243748',
 '#243848',
 '#253948',
 '#263a49',
 '#263a49',
 '#273b4a',
 '#273c4a',
 '#283d4a',
 '#283d4b',
 '#293e4b',
 '#293f4b',
 '#2a404c',
 '#2b404c',
 '#2b414c',
 '#2c424d',
 '#2c434d',
 '#2d434d',
 '#2d444e',
 '#2e454e',
 '#2f464f',
 '#2e4750',
 '#2e4851',
 '#2e4a52',
 '#2e4b53',
 '#2e4d54',
 '#2e4e55',
 '#2e4f56',
 '#2e5157',
 '#2e5259',
 '#2e545a',
 '#2e555b',
 '#2e575c',
 '#2e585d',
 '#2e595e',
 '#2d5b5f',
 '#2d5c60',
 '#2d5e62',
 '#2d5f63',
 '#2d6064',
 '#2d6265',
 '#2d6366',
 '#2d6567',
 '#2d6668',
 '#2d6869',
 '#2d696a',
 '#2d6a6c',
 '#2d6c6d',
 '#2d6d6e',
 '#2c6f6f',
 '#2c7070',
 '#2c7171',
 '#2c7372',
 '#2c7473',
 '#2c7675',
 '#2c7776',
 '#2c7977',
 '#2c7a78',
 '#2c7b79',
 '#2c7d7a',
 '#2c7e7b',
 '#2c807c',
 '#2c817e',
 '#2b827f',
 '#2b8480',
 '#2b8581',
 '#2b8782',
 '#2b8883',
 '#2b8a84',
 '#2b8b85',
 '#2b8c86',
 '#2b8e88',
 '#2b8f89',
 '#2b918a',
 '#2b928b',
 '#2b938c',
 '#2b958d',
 '#2a968e',
 '#2a988f',
 '#2a9991',
 '#2a9b92',
 '#2a9c93',
 '#2a9d94',
 '#2a9f95',
 '#2aa096',
 '#2aa297',
 '#2aa398',
 '#2aa499',
 '#2aa69b',
 '#2aa79c',
 '#2aa99d',
 '#29aa9e',
 '#29ac9f',
 '#29ada0',
 '#29aea1',
 '#29b0a2',
 '#29b1a4',
 '#29b3a5',
 '#29b4a6',
 '#29b5a7',
 '#29b7a8',
 '#29b8a9',
 '#29baaa',
 '#29bbab',
 '#29bdad',
 '#2abdad',
 '#2bbdae',
 '#2dbeae',
 '#2ebeaf',
 '#30bfaf',
 '#31bfb0',
 '#33c0b0',
 '#34c0b1',
 '#36c1b1',
 '#37c1b2',
 '#39c2b3',
 '#3ac2b3',
 '#3cc3b4',
 '#3dc3b4',
 '#3fc4b5',
 '#40c4b5',
 '#42c5b6',
 '#43c5b6',
 '#45c6b7',
 '#46c6b7',
 '#48c7b8',
 '#49c7b9',
 '#4bc8b9',
 '#4cc8ba',
 '#4ec9ba',
 '#4fc9bb',
 '#51cabb',
 '#52cabc',
 '#54cbbc',
 '#55cbbd',
 '#57ccbd',
 '#58ccbe',
 '#5acdbf',
 '#5bcdbf',
 '#5dcec0',
 '#5ecec0',
 '#60cfc1',
 '#61cfc1',
 '#63d0c2',
 '#64d0c2',
 '#66d1c3',
 '#67d1c4',
 '#68d1c4',
 '#6ad2c5',
 '#6bd2c5',
 '#6dd3c6',
 '#6ed3c6',
 '#70d4c7',
 '#71d4c7',
 '#73d5c8',
 '#74d5c8',
 '#76d6c9',
 '#77d6ca',
 '#79d7ca',
 '#7ad7cb',
 '#7cd8cb',
 '#7dd8cc',
 '#7fd9cc',
 '#80d9cd',
 '#82dacd',
 '#83dace',
 '#85dbce',
 '#86dbcf',
 '#88dcd0',
 '#89dcd0',
 '#8bddd1',
 '#8cddd1',
 '#8eded2',
 '#8fded2',
 '#91dfd3',
 '#92dfd3',
 '#94e0d4',
 '#95e0d4',
 '#97e1d5',
 '#98e1d6',
 '#9ae2d6',
 '#9be2d7',
 '#9de3d7',
 '#9ee3d8',
 '#a0e4d8',
 '#a1e4d9',
 '#a3e5d9',
 '#a4e5da',
 '#a6e6db']

blink = ['#040816',
            '#414C83',
             '#7A86B7',
             '#B2B4D8',
             '#F1B9B0',
             '#F59E98',
             '#D97D79']
blink256 = ['#d97d79',
 '#d97d79',
 '#da7e7a',
 '#db7f7b',
 '#db807c',
 '#dc817c',
 '#dd817d',
 '#dd827e',
 '#de837f',
 '#df847f',
 '#df8580',
 '#e08581',
 '#e18682',
 '#e18782',
 '#e28883',
 '#e38984',
 '#e38985',
 '#e48a85',
 '#e58b86',
 '#e58c87',
 '#e68d88',
 '#e78d88',
 '#e88e89',
 '#e88f8a',
 '#e9908b',
 '#ea918b',
 '#ea918c',
 '#eb928d',
 '#ec938e',
 '#ec948e',
 '#ed958f',
 '#ee9590',
 '#ee9691',
 '#ef9791',
 '#f09892',
 '#f09993',
 '#f19994',
 '#f29a94',
 '#f29b95',
 '#f39c96',
 '#f49d97',
 '#f59e98',
 '#f49e98',
 '#f49f99',
 '#f49f99',
 '#f4a09a',
 '#f4a19a',
 '#f4a19b',
 '#f4a29c',
 '#f4a39c',
 '#f4a39d',
 '#f4a49d',
 '#f3a59e',
 '#f3a59f',
 '#f3a69f',
 '#f3a7a0',
 '#f3a7a0',
 '#f3a8a1',
 '#f3a9a1',
 '#f3a9a2',
 '#f3aaa3',
 '#f3aba3',
 '#f2aba4',
 '#f2aca4',
 '#f2ada5',
 '#f2ada6',
 '#f2aea6',
 '#f2afa7',
 '#f2afa7',
 '#f2b0a8',
 '#f2b1a8',
 '#f2b1a9',
 '#f1b2aa',
 '#f1b3aa',
 '#f1b3ab',
 '#f1b4ab',
 '#f1b5ac',
 '#f1b5ad',
 '#f1b6ad',
 '#f1b7ae',
 '#f1b7ae',
 '#f1b8af',
 '#f1b9b0',
 '#efb8b0',
 '#edb8b1',
 '#ecb8b2',
 '#eab8b3',
 '#e9b8b4',
 '#e7b8b5',
 '#e6b8b6',
 '#e4b8b7',
 '#e3b7b8',
 '#e1b7b9',
 '#e0b7ba',
 '#deb7bb',
 '#ddb7bc',
 '#dbb7bd',
 '#d9b7be',
 '#d8b7bf',
 '#d6b6c0',
 '#d5b6c1',
 '#d3b6c2',
 '#d2b6c3',
 '#d0b6c4',
 '#cfb6c5',
 '#cdb6c6',
 '#ccb6c7',
 '#cab5c8',
 '#c9b5c9',
 '#c7b5ca',
 '#c5b5cb',
 '#c4b5cc',
 '#c2b5cd',
 '#c1b5ce',
 '#bfb5cf',
 '#beb4d0',
 '#bcb4d1',
 '#bbb4d2',
 '#b9b4d3',
 '#b8b4d4',
 '#b6b4d5',
 '#b5b4d6',
 '#b3b4d7',
 '#b2b4d8',
 '#b0b2d7',
 '#afb1d6',
 '#adb0d5',
 '#acafd4',
 '#abaed3',
 '#a9add3',
 '#a8acd2',
 '#a7abd1',
 '#a5a9d0',
 '#a4a8cf',
 '#a2a7cf',
 '#a1a6ce',
 '#a0a5cd',
 '#9ea4cc',
 '#9da3cb',
 '#9ca2cb',
 '#9aa0ca',
 '#999fc9',
 '#989ec8',
 '#969dc7',
 '#959cc7',
 '#939bc6',
 '#929ac5',
 '#9199c4',
 '#8f97c3',
 '#8e96c3',
 '#8d95c2',
 '#8b94c1',
 '#8a93c0',
 '#8992bf',
 '#8791bf',
 '#8690be',
 '#848ebd',
 '#838dbc',
 '#828cbb',
 '#808bbb',
 '#7f8aba',
 '#7e89b9',
 '#7c88b8',
 '#7b87b7',
 '#7a86b7',
 '#7884b5',
 '#7783b4',
 '#7581b3',
 '#7480b1',
 '#737eb0',
 '#717daf',
 '#707cae',
 '#6e7aac',
 '#6d79ab',
 '#6c77aa',
 '#6a76a9',
 '#6975a7',
 '#6773a6',
 '#6672a5',
 '#6570a3',
 '#636fa2',
 '#626da1',
 '#606ca0',
 '#5f6b9e',
 '#5e699d',
 '#5c689c',
 '#5b669b',
 '#5a6599',
 '#586498',
 '#576297',
 '#556196',
 '#545f94',
 '#535e93',
 '#515c92',
 '#505b90',
 '#4e5a8f',
 '#4d588e',
 '#4c578d',
 '#4a558b',
 '#49548a',
 '#475389',
 '#465188',
 '#455086',
 '#434e85',
 '#424d84',
 '#414c83',
 '#3f4a80',
 '#3e487d',
 '#3c477b',
 '#3b4578',
 '#394375',
 '#384273',
 '#364070',
 '#353e6d',
 '#333d6b',
 '#323b68',
 '#303965',
 '#2f3863',
 '#2d3660',
 '#2c345d',
 '#2a335b',
 '#293158',
 '#272f55',
 '#262e53',
 '#242c50',
 '#232a4d',
 '#21294b',
 '#202748',
 '#1e2545',
 '#1d2443',
 '#1b2240',
 '#1a203d',
 '#181f3b',
 '#171d38',
 '#151b35',
 '#141a33',
 '#121830',
 '#11162d',
 '#0f152b',
 '#0e1328',
 '#0c1125',
 '#0b1023',
 '#090e20',
 '#080c1d',
 '#060b1b',
 '#050918',
 '#040816']

betan = ["#73100B",
        "#832F2B",
        "#944F4D",
        "#B07F7D",
        "#C09B9A",
        "#D7BDBC",
        "#B3B2B2",
        "#8F8F8F",
        "#585858" ]
betan256 = ['#73100b',
 '#73110c',
 '#74120d',
 '#74130e',
 '#75140f',
 '#751510',
 '#761611',
 '#761712',
 '#771813',
 '#771914',
 '#781a15',
 '#781b16',
 '#791c17',
 '#791d18',
 '#7a1e19',
 '#7a1f1a',
 '#7b201b',
 '#7b211c',
 '#7c221d',
 '#7c231e',
 '#7d241f',
 '#7d2520',
 '#7e2621',
 '#7e2722',
 '#7f2823',
 '#7f2924',
 '#802a25',
 '#802b26',
 '#812c27',
 '#812d28',
 '#822e29',
 '#832f2b',
 '#83302c',
 '#84312d',
 '#84322e',
 '#85332f',
 '#853430',
 '#863531',
 '#863632',
 '#873733',
 '#873834',
 '#883935',
 '#893a37',
 '#893b38',
 '#8a3c39',
 '#8a3d3a',
 '#8b3e3b',
 '#8b3f3c',
 '#8c403d',
 '#8c413e',
 '#8d423f',
 '#8d4340',
 '#8e4442',
 '#8f4543',
 '#8f4644',
 '#904745',
 '#904846',
 '#914947',
 '#914a48',
 '#924b49',
 '#924c4a',
 '#934d4b',
 '#944f4d',
 '#94504e',
 '#955250',
 '#965351',
 '#975553',
 '#985654',
 '#995856',
 '#9a5957',
 '#9b5b59',
 '#9c5c5a',
 '#9d5e5c',
 '#9d605e',
 '#9e615f',
 '#9f6361',
 '#a06462',
 '#a16664',
 '#a26765',
 '#a36967',
 '#a46a68',
 '#a56c6a',
 '#a66d6b',
 '#a66f6d',
 '#a7716f',
 '#a87270',
 '#a97472',
 '#aa7573',
 '#ab7775',
 '#ac7876',
 '#ad7a78',
 '#ae7b79',
 '#af7d7b',
 '#b07f7d',
 '#b07f7d',
 '#b1807e',
 '#b1817f',
 '#b28280',
 '#b28381',
 '#b38482',
 '#b38583',
 '#b48684',
 '#b48785',
 '#b58886',
 '#b58887',
 '#b68988',
 '#b68a89',
 '#b78b8a',
 '#b78c8b',
 '#b88d8b',
 '#b88e8c',
 '#b98f8d',
 '#b9908e',
 '#ba918f',
 '#ba9190',
 '#bb9291',
 '#bb9392',
 '#bc9493',
 '#bc9594',
 '#bd9695',
 '#bd9796',
 '#be9897',
 '#be9998',
 '#bf9a99',
 '#c09b9a',
 '#c09c9b',
 '#c19d9c',
 '#c29e9d',
 '#c29f9e',
 '#c3a09f',
 '#c4a1a0',
 '#c5a2a1',
 '#c5a3a2',
 '#c6a4a3',
 '#c7a5a4',
 '#c8a7a6',
 '#c8a8a7',
 '#c9a9a8',
 '#caaaa9',
 '#cbabaa',
 '#cbacab',
 '#ccadac',
 '#cdaead',
 '#ceafae',
 '#ceb0af',
 '#cfb2b1',
 '#d0b3b2',
 '#d1b4b3',
 '#d1b5b4',
 '#d2b6b5',
 '#d3b7b6',
 '#d4b8b7',
 '#d4b9b8',
 '#d5bab9',
 '#d6bbba',
 '#d7bdbc',
 '#d5bcbb',
 '#d4bcbb',
 '#d3bbbb',
 '#d2bbba',
 '#d1bbba',
 '#d0baba',
 '#cebab9',
 '#cdbab9',
 '#ccb9b9',
 '#cbb9b8',
 '#cab9b8',
 '#c9b8b8',
 '#c7b8b7',
 '#c6b8b7',
 '#c5b7b7',
 '#c4b7b6',
 '#c3b6b6',
 '#c2b6b6',
 '#c0b6b5',
 '#bfb5b5',
 '#beb5b5',
 '#bdb5b4',
 '#bcb4b4',
 '#bbb4b4',
 '#b9b4b3',
 '#b8b3b3',
 '#b7b3b3',
 '#b6b3b2',
 '#b5b2b2',
 '#b4b2b2',
 '#b3b2b2',
 '#b1b0b0',
 '#b0afaf',
 '#afaeae',
 '#aeadad',
 '#adacac',
 '#acabab',
 '#aaaaaa',
 '#a9a8a8',
 '#a8a7a7',
 '#a7a6a6',
 '#a6a5a5',
 '#a5a4a4',
 '#a3a3a3',
 '#a2a2a2',
 '#a1a1a1',
 '#a09f9f',
 '#9f9e9e',
 '#9e9d9d',
 '#9c9c9c',
 '#9b9b9b',
 '#9a9a9a',
 '#999999',
 '#989898',
 '#979696',
 '#959595',
 '#949494',
 '#939393',
 '#929292',
 '#919191',
 '#909090',
 '#8f8f8f',
 '#8d8d8d',
 '#8b8b8b',
 '#898989',
 '#878787',
 '#868686',
 '#848484',
 '#828282',
 '#808080',
 '#7f7f7f',
 '#7d7d7d',
 '#7b7b7b',
 '#797979',
 '#777777',
 '#767676',
 '#747474',
 '#727272',
 '#707070',
 '#6f6f6f',
 '#6d6d6d',
 '#6b6b6b',
 '#696969',
 '#676767',
 '#666666',
 '#646464',
 '#626262',
 '#606060',
 '#5f5f5f',
 '#5d5d5d',
 '#5b5b5b',
 '#595959',
 '#585858']

rue = ["#973D46",
    "#6D2A31",
    "#CFBDBF",
    "#5977B5",
    "#263452",
    "#90AAD9"]
rue256 = ['#000000',
 '#020101',
 '#050202',
 '#070303',
 '#0a0404',
 '#0d0505',
 '#0f0607',
 '#120708',
 '#150809',
 '#17090a',
 '#1a0a0b',
 '#1d0b0d',
 '#1f0c0e',
 '#220d0f',
 '#250e10',
 '#270f11',
 '#2a1013',
 '#2d1114',
 '#2f1215',
 '#321316',
 '#351417',
 '#371519',
 '#3a161a',
 '#3d171b',
 '#3f181c',
 '#42191d',
 '#451a1f',
 '#471b20',
 '#4a1c21',
 '#4d1d22',
 '#4f1e23',
 '#521f25',
 '#552026',
 '#572127',
 '#5a2228',
 '#5d2329',
 '#5f242b',
 '#62252c',
 '#65262d',
 '#67272e',
 '#6a282f',
 '#6d2a31',
 '#6e2a31',
 '#6f2a32',
 '#702b32',
 '#712b33',
 '#722c33',
 '#732c34',
 '#742d34',
 '#752d35',
 '#762e35',
 '#772e36',
 '#782f36',
 '#792f37',
 '#7a3037',
 '#7b3038',
 '#7c3038',
 '#7d3139',
 '#7e3139',
 '#7f323a',
 '#80323a',
 '#81333b',
 '#82333b',
 '#83343c',
 '#84343c',
 '#85353d',
 '#86353d',
 '#87363e',
 '#88363e',
 '#89363f',
 '#8a373f',
 '#8b3740',
 '#8c3840',
 '#8d3841',
 '#8e3941',
 '#8f3942',
 '#903a42',
 '#913a43',
 '#923b43',
 '#933b44',
 '#943c44',
 '#953c45',
 '#973d46',
 '#984048',
 '#99434b',
 '#9b464e',
 '#9c4951',
 '#9d4c54',
 '#9f4f57',
 '#a0525a',
 '#a1555d',
 '#a35960',
 '#a45c63',
 '#a65f66',
 '#a76269',
 '#a8656c',
 '#aa686f',
 '#ab6b72',
 '#ac6e75',
 '#ae7278',
 '#af757b',
 '#b0787e',
 '#b27b81',
 '#b37e83',
 '#b58186',
 '#b68489',
 '#b7878c',
 '#b98b8f',
 '#ba8e92',
 '#bb9195',
 '#bd9498',
 '#be979b',
 '#bf9a9e',
 '#c19da1',
 '#c2a0a4',
 '#c4a4a7',
 '#c5a7aa',
 '#c6aaad',
 '#c8adb0',
 '#c9b0b3',
 '#cab3b6',
 '#ccb6b9',
 '#cdb9bc',
 '#cfbdbf',
 '#cdbcbf',
 '#cbbcc0',
 '#cabbc0',
 '#c8bbc1',
 '#c7bac2',
 '#c5bac2',
 '#c4b9c3',
 '#c2b9c4',
 '#c1b8c4',
 '#bfb8c5',
 '#beb7c5',
 '#bcb7c6',
 '#bbb6c7',
 '#b9b6c7',
 '#b7b6c8',
 '#b6b5c9',
 '#b4b5c9',
 '#b3b4ca',
 '#b1b4cb',
 '#b0b3cb',
 '#aeb3cc',
 '#adb2cc',
 '#abb2cd',
 '#aab1ce',
 '#a8b1ce',
 '#a7b0cf',
 '#a5b0d0',
 '#a3b0d0',
 '#a2afd1',
 '#a0afd2',
 '#9faed2',
 '#9daed3',
 '#9cadd3',
 '#9aadd4',
 '#99acd5',
 '#97acd5',
 '#96abd6',
 '#94abd7',
 '#93aad7',
 '#91aad8',
 '#90aad9',
 '#8ea8d8',
 '#8da7d7',
 '#8ba6d6',
 '#8aa5d5',
 '#89a3d4',
 '#87a2d3',
 '#86a1d2',
 '#85a0d1',
 '#839ed1',
 '#829dd0',
 '#819ccf',
 '#7f9bce',
 '#7e99cd',
 '#7d98cc',
 '#7b97cb',
 '#7a96ca',
 '#7994ca',
 '#7793c9',
 '#7692c8',
 '#7591c7',
 '#738fc6',
 '#728ec5',
 '#718dc4',
 '#6f8cc3',
 '#6e8ac3',
 '#6d89c2',
 '#6b88c1',
 '#6a87c0',
 '#6985bf',
 '#6784be',
 '#6683bd',
 '#6582bc',
 '#6380bc',
 '#627fbb',
 '#617eba',
 '#5f7db9',
 '#5e7bb8',
 '#5d7ab7',
 '#5b79b6',
 '#5a78b5',
 '#5977b5',
 '#5775b2',
 '#5673b0',
 '#5572ad',
 '#5470ab',
 '#526ea8',
 '#516da6',
 '#506ba4',
 '#4f69a1',
 '#4d689f',
 '#4c669c',
 '#4b659a',
 '#4a6398',
 '#486195',
 '#476093',
 '#465e90',
 '#455c8e',
 '#435b8b',
 '#425989',
 '#415787',
 '#405684',
 '#3e5482',
 '#3d537f',
 '#3c517d',
 '#3b4f7b',
 '#394e78',
 '#384c76',
 '#374a73',
 '#364971',
 '#34476e',
 '#33456c',
 '#32446a',
 '#314267',
 '#2f4165',
 '#2e3f62',
 '#2d3d60',
 '#2c3c5e',
 '#2a3a5b',
 '#293859',
 '#283756',
 '#273554',
 '#263452']

otterpop = ["#a90636",
            "#ff616b",
            "#ff989c",
            "#eeddee",
            "#b8b8ff",
            "#4d52de",
             "#3400a3"
                 ]
otterpop20 = ['#a90636',
              '#c52447',
              '#e24259',
              '#ff616b',
              '#ff737b',
              '#ff858b',
              '#ff989c',
              '#f9afb7',
              '#f3c6d2',
              '#eeddee',
              '#dcd0f3',
              '#cac4f9',
              '#b8b8ff',
              '#9496f4',
              '#7074e9',
              '#4d52de',
              '#4436ca',
              '#3c1bb6',
              '#3400a3']
otterpop256 = ['#a90636',
 '#ab0837',
 '#ad0a38',
 '#af0c39',
 '#b10e3b',
 '#b3113c',
 '#b5133d',
 '#b7153f',
 '#b91740',
 '#bb1941',
 '#bd1c42',
 '#c01e44',
 '#c22045',
 '#c42246',
 '#c62548',
 '#c82749',
 '#ca294a',
 '#cc2b4b',
 '#ce2d4d',
 '#d0304e',
 '#d2324f',
 '#d53451',
 '#d73652',
 '#d93953',
 '#db3b55',
 '#dd3d56',
 '#df3f57',
 '#e14158',
 '#e3445a',
 '#e5465b',
 '#e7485c',
 '#ea4a5e',
 '#ec4d5f',
 '#ee4f60',
 '#f05161',
 '#f25363',
 '#f45564',
 '#f65865',
 '#f85a67',
 '#fa5c68',
 '#fc5e69',
 '#ff616b',
 '#ff626c',
 '#ff636d',
 '#ff656e',
 '#ff666f',
 '#ff6770',
 '#ff6972',
 '#ff6a73',
 '#ff6b74',
 '#ff6d75',
 '#ff6e76',
 '#ff6f78',
 '#ff7179',
 '#ff727a',
 '#ff737b',
 '#ff757c',
 '#ff767e',
 '#ff777f',
 '#ff7980',
 '#ff7a81',
 '#ff7b82',
 '#ff7d84',
 '#ff7e85',
 '#ff7f86',
 '#ff8187',
 '#ff8288',
 '#ff838a',
 '#ff858b',
 '#ff868c',
 '#ff878d',
 '#ff898e',
 '#ff8a90',
 '#ff8b91',
 '#ff8d92',
 '#ff8e93',
 '#ff8f94',
 '#ff9196',
 '#ff9297',
 '#ff9398',
 '#ff9599',
 '#ff969a',
 '#ff989c',
 '#fe999e',
 '#fe9ba0',
 '#fd9da2',
 '#fd9ea4',
 '#fca0a6',
 '#fca2a8',
 '#fca3aa',
 '#fba5ac',
 '#fba7ae',
 '#faa8b0',
 '#faaab2',
 '#faacb4',
 '#f9adb6',
 '#f9afb8',
 '#f8b1ba',
 '#f8b2bc',
 '#f7b4be',
 '#f7b6c0',
 '#f7b7c2',
 '#f6b9c4',
 '#f6bbc6',
 '#f5bdc8',
 '#f5beca',
 '#f5c0cc',
 '#f4c2ce',
 '#f4c3d0',
 '#f3c5d2',
 '#f3c7d4',
 '#f2c8d6',
 '#f2cad8',
 '#f2ccda',
 '#f1cddc',
 '#f1cfde',
 '#f0d1e0',
 '#f0d2e2',
 '#f0d4e4',
 '#efd6e6',
 '#efd7e8',
 '#eed9ea',
 '#eedbec',
 '#eeddee',
 '#ecdcee',
 '#ebdbee',
 '#eadaef',
 '#e8d9ef',
 '#e7d8f0',
 '#e6d7f0',
 '#e4d6f0',
 '#e3d5f1',
 '#e2d4f1',
 '#e0d3f2',
 '#dfd3f2',
 '#ded2f2',
 '#dcd1f3',
 '#dbd0f3',
 '#dacff4',
 '#d8cef4',
 '#d7cdf5',
 '#d6ccf5',
 '#d4cbf5',
 '#d3caf6',
 '#d2caf6',
 '#d1c9f7',
 '#cfc8f7',
 '#cec7f7',
 '#cdc6f8',
 '#cbc5f8',
 '#cac4f9',
 '#c9c3f9',
 '#c7c2fa',
 '#c6c1fa',
 '#c5c1fa',
 '#c3c0fb',
 '#c2bffb',
 '#c1befc',
 '#bfbdfc',
 '#bebcfc',
 '#bdbbfd',
 '#bbbafd',
 '#bab9fe',
 '#b9b8fe',
 '#b8b8ff',
 '#b5b5fe',
 '#b2b3fd',
 '#b0b0fc',
 '#adaefb',
 '#aaabfa',
 '#a8a9fa',
 '#a5a6f9',
 '#a3a4f8',
 '#a0a1f7',
 '#9d9ff6',
 '#9b9cf6',
 '#989af5',
 '#9697f4',
 '#9395f3',
 '#9092f2',
 '#8e90f2',
 '#8b8df1',
 '#898bf0',
 '#8688ef',
 '#8386ee',
 '#8183ee',
 '#7e81ed',
 '#7b7eec',
 '#797ceb',
 '#7679ea',
 '#7477ea',
 '#7174e9',
 '#6e72e8',
 '#6c6fe7',
 '#696de6',
 '#676ae6',
 '#6468e5',
 '#6165e4',
 '#5f63e3',
 '#5c60e2',
 '#5a5ee2',
 '#575be1',
 '#5459e0',
 '#5256df',
 '#4f54de',
 '#4d52de',
 '#4c50dc',
 '#4b4edb',
 '#4b4cd9',
 '#4a4ad8',
 '#4948d6',
 '#4946d5',
 '#4844d3',
 '#4842d2',
 '#4740d1',
 '#463ecf',
 '#463cce',
 '#453acc',
 '#4538cb',
 '#4436c9',
 '#4334c8',
 '#4332c6',
 '#4230c5',
 '#422ec4',
 '#412cc2',
 '#402ac1',
 '#4028bf',
 '#3f26be',
 '#3e24bc',
 '#3e22bb',
 '#3d20ba',
 '#3d1eb8',
 '#3c1cb7',
 '#3b1ab5',
 '#3b18b4',
 '#3a16b2',
 '#3a14b1',
 '#3912af',
 '#3810ae',
 '#380ead',
 '#370cab',
 '#370aaa',
 '#3608a8',
 '#3506a7',
 '#3504a5',
 '#3402a4',
 '#3400a3']

gummi = ["#a90636",
         "#ff616b",
         "#ffcfc4",
         "#abf5ed",
         "#008aa1",
         "#005a71"]
gummi20 = ['#a90636',
 '#c52447',
 '#e24259',
 '#ff616b',
 '#ff8588',
 '#ffaaa6',
 '#ffcfc4',
 '#e3dbd1',
 '#c7e8df',
 '#abf5ed',
 '#72d1d3',
 '#39adba',
 '#008aa1',
 '#007a91',
 '#006a81',
 '#005a71']
gummi256 = ['#a90636',
 '#aa0737',
 '#ac0938',
 '#ae0b39',
 '#af0d3a',
 '#b10f3b',
 '#b3103c',
 '#b5123d',
 '#b6143e',
 '#b8163f',
 '#ba1840',
 '#bb1a41',
 '#bd1b42',
 '#bf1d43',
 '#c11f44',
 '#c22145',
 '#c42346',
 '#c62448',
 '#c72649',
 '#c9284a',
 '#cb2a4b',
 '#cd2c4c',
 '#ce2e4d',
 '#d02f4e',
 '#d2314f',
 '#d43350',
 '#d53551',
 '#d73752',
 '#d93853',
 '#da3a54',
 '#dc3c55',
 '#de3e56',
 '#e04057',
 '#e14258',
 '#e3435a',
 '#e5455b',
 '#e6475c',
 '#e8495d',
 '#ea4b5e',
 '#ec4c5f',
 '#ed4e60',
 '#ef5061',
 '#f15262',
 '#f25463',
 '#f45664',
 '#f65765',
 '#f85966',
 '#f95b67',
 '#fb5d68',
 '#fd5f69',
 '#ff616b',
 '#ff636c',
 '#ff656e',
 '#ff6770',
 '#ff6972',
 '#ff6c73',
 '#ff6e75',
 '#ff7077',
 '#ff7279',
 '#ff747b',
 '#ff777c',
 '#ff797e',
 '#ff7b80',
 '#ff7d82',
 '#ff7f83',
 '#ff8285',
 '#ff8487',
 '#ff8689',
 '#ff888b',
 '#ff8a8c',
 '#ff8d8e',
 '#ff8f90',
 '#ff9192',
 '#ff9393',
 '#ff9595',
 '#ff9897',
 '#ff9a99',
 '#ff9c9b',
 '#ff9e9c',
 '#ffa09e',
 '#ffa3a0',
 '#ffa5a2',
 '#ffa7a3',
 '#ffa9a5',
 '#ffaba7',
 '#ffaea9',
 '#ffb0ab',
 '#ffb2ac',
 '#ffb4ae',
 '#ffb6b0',
 '#ffb9b2',
 '#ffbbb3',
 '#ffbdb5',
 '#ffbfb7',
 '#ffc1b9',
 '#ffc4bb',
 '#ffc6bc',
 '#ffc8be',
 '#ffcac0',
 '#ffccc2',
 '#ffcfc4',
 '#fdcfc4',
 '#fbd0c5',
 '#f9d1c6',
 '#f8d2c7',
 '#f6d2c8',
 '#f4d3c8',
 '#f3d4c9',
 '#f1d5ca',
 '#efd5cb',
 '#eed6cc',
 '#ecd7cd',
 '#ead8cd',
 '#e9d8ce',
 '#e7d9cf',
 '#e5dad0',
 '#e4dbd1',
 '#e2dbd1',
 '#e0dcd2',
 '#dfddd3',
 '#ddded4',
 '#dbded5',
 '#dadfd6',
 '#d8e0d6',
 '#d6e1d7',
 '#d5e2d8',
 '#d3e2d9',
 '#d1e3da',
 '#cfe4da',
 '#cee5db',
 '#cce5dc',
 '#cae6dd',
 '#c9e7de',
 '#c7e8df',
 '#c5e8df',
 '#c4e9e0',
 '#c2eae1',
 '#c0ebe2',
 '#bfebe3',
 '#bdece3',
 '#bbede4',
 '#baeee5',
 '#b8eee6',
 '#b6efe7',
 '#b5f0e8',
 '#b3f1e8',
 '#b1f1e9',
 '#b0f2ea',
 '#aef3eb',
 '#acf4ec',
 '#abf5ed',
 '#a7f2eb',
 '#a4f0e9',
 '#a0eee8',
 '#9dece6',
 '#99eae5',
 '#96e8e3',
 '#93e6e2',
 '#8fe3e0',
 '#8ce1df',
 '#88dfdd',
 '#85dddc',
 '#81dbda',
 '#7ed9d9',
 '#7bd7d7',
 '#77d4d6',
 '#74d2d4',
 '#70d0d3',
 '#6dced1',
 '#6accd0',
 '#66cace',
 '#63c8cd',
 '#5fc5cb',
 '#5cc3ca',
 '#58c1c8',
 '#55bfc7',
 '#52bdc5',
 '#4ebbc3',
 '#4bb9c2',
 '#47b6c0',
 '#44b4bf',
 '#40b2bd',
 '#3db0bc',
 '#3aaeba',
 '#36acb9',
 '#33aab7',
 '#2fa7b6',
 '#2ca5b4',
 '#29a3b3',
 '#25a1b1',
 '#229fb0',
 '#1e9dae',
 '#1b9bad',
 '#1798ab',
 '#1496aa',
 '#1194a8',
 '#0d92a7',
 '#0a90a5',
 '#068ea4',
 '#038ca2',
 '#008aa1',
 '#0089a0',
 '#00889f',
 '#00879e',
 '#00869d',
 '#00859c',
 '#00849b',
 '#00839a',
 '#008299',
 '#008198',
 '#008097',
 '#007f96',
 '#007e95',
 '#007d94',
 '#007c93',
 '#007b92',
 '#007a91',
 '#007990',
 '#00788f',
 '#00778e',
 '#00768d',
 '#00758c',
 '#00748b',
 '#00738a',
 '#007289',
 '#007289',
 '#007188',
 '#007087',
 '#006f86',
 '#006e85',
 '#006d84',
 '#006c83',
 '#006b82',
 '#006a81',
 '#006980',
 '#00687f',
 '#00677e',
 '#00667d',
 '#00657c',
 '#00647b',
 '#00637a',
 '#006279',
 '#006178',
 '#006077',
 '#005f76',
 '#005e75',
 '#005d74',
 '#005c73',
 '#005b72',
 '#005a71',
 '#005a71']

emporium = ["#2D1611",
            "#5E1615",
            "#881A12",
            "#B4281F",
              "#CB4324",
              "#D06830",
              "#D38B3A",
              "#D3AB3A",
              "#DFBB44",
              "#EAD9A3",
                  '#EDEBE0',
                  '#A7BAA8',
                  '#759E8E',
                  '#5A8F85',
                  '#5C9288',
                  '#378078',
                  '#2F6F6A',
                  '#265A54',
                  '#1C4743',
                  '#1C2A1E'
             ]
emporium256 = ['#2d1611',
 '#311611',
 '#351611',
 '#391612',
 '#3d1612',
 '#411612',
 '#451613',
 '#491613',
 '#4d1613',
 '#511614',
 '#551614',
 '#591614',
 '#5e1615',
 '#611614',
 '#651614',
 '#681714',
 '#6c1714',
 '#6f1713',
 '#731813',
 '#761813',
 '#7a1813',
 '#7d1912',
 '#811912',
 '#841912',
 '#881a12',
 '#8b1b13',
 '#8f1c14',
 '#931d15',
 '#961e16',
 '#9a1f17',
 '#9e2118',
 '#a12219',
 '#a5231a',
 '#a9241b',
 '#ac251c',
 '#b0261d',
 '#b4281f',
 '#b52a1f',
 '#b72c1f',
 '#b92e20',
 '#bb3120',
 '#bd3321',
 '#bf3521',
 '#c13721',
 '#c33a22',
 '#c53c22',
 '#c73e23',
 '#c94023',
 '#cb4324',
 '#cb4625',
 '#cb4926',
 '#cc4c27',
 '#cc4f28',
 '#cd5229',
 '#cd552a',
 '#cd582b',
 '#ce5b2c',
 '#ce5e2d',
 '#cf612e',
 '#cf642f',
 '#d06830',
 '#d06a30',
 '#d06d31',
 '#d07032',
 '#d17333',
 '#d17634',
 '#d17935',
 '#d17c35',
 '#d27f36',
 '#d28237',
 '#d28538',
 '#d28839',
 '#d38b3a',
 '#d38d3a',
 '#d3903a',
 '#d3933a',
 '#d3953a',
 '#d3983a',
 '#d39b3a',
 '#d39d3a',
 '#d3a03a',
 '#d3a33a',
 '#d3a53a',
 '#d3a83a',
 '#d3ab3a',
 '#d4ac3a',
 '#d5ad3b',
 '#d6af3c',
 '#d7b03d',
 '#d8b13e',
 '#d9b33f',
 '#dab43f',
 '#dbb540',
 '#dcb741',
 '#ddb842',
 '#deb943',
 '#dfbb44',
 '#dfbd4b',
 '#e0c053',
 '#e1c25b',
 '#e2c563',
 '#e3c76b',
 '#e4ca73',
 '#e5cc7b',
 '#e6cf83',
 '#e7d18b',
 '#e8d493',
 '#e9d69b',
 '#ead9a3',
 '#eadaa8',
 '#eadcad',
 '#eaddb2',
 '#ebdfb7',
 '#ebe0bc',
 '#ebe2c1',
 '#ebe3c6',
 '#ece5cb',
 '#ece6d0',
 '#ece8d5',
 '#ece9da',
 '#edebe0',
 '#e7e6db',
 '#e1e2d6',
 '#dbded2',
 '#d5dacd',
 '#cfd6c8',
 '#cad2c4',
 '#c4cebf',
 '#becaba',
 '#b8c6b6',
 '#b2c2b1',
 '#acbeac',
 '#a7baa8',
 '#a2b7a5',
 '#9eb5a3',
 '#9ab3a1',
 '#96b09f',
 '#92ae9d',
 '#8eac9b',
 '#89a998',
 '#85a796',
 '#81a594',
 '#7da292',
 '#79a090',
 '#759e8e',
 '#729c8d',
 '#709b8c',
 '#6e9a8b',
 '#6c998b',
 '#69978a',
 '#679689',
 '#659588',
 '#639488',
 '#609287',
 '#5e9186',
 '#5c9085',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5a8f85',
 '#5a9086',
 '#5a9086',
 '#5b9086',
 '#5b9086',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5b9187',
 '#5c9288',
 '#589086',
 '#558f85',
 '#528d84',
 '#4f8c82',
 '#4c8a81',
 '#498980',
 '#46877e',
 '#43867d',
 '#40847c',
 '#3d837a',
 '#3a8179',
 '#378078',
 '#367e76',
 '#357d75',
 '#357b74',
 '#347a73',
 '#337872',
 '#337771',
 '#32766f',
 '#31746e',
 '#31736d',
 '#30716c',
 '#2f706b',
 '#2f6f6a',
 '#2e6d68',
 '#2d6b66',
 '#2c6964',
 '#2c6862',
 '#2b6660',
 '#2a645f',
 '#29625d',
 '#29615b',
 '#285f59',
 '#275d57',
 '#265b55',
 '#265a54',
 '#255852',
 '#245651',
 '#23554f',
 '#22534e',
 '#21524c',
 '#21504b',
 '#204e4a',
 '#1f4d48',
 '#1e4b47',
 '#1d4a45',
 '#1c4844',
 '#1c4743',
 '#1c443f',
 '#1c423c',
 '#1c3f39',
 '#1c3d36',
 '#1c3a33',
 '#1c3830',
 '#1c362d',
 '#1c332a',
 '#1c3127',
 '#1c2e24',
 '#1c2c21',
 '#1c2a1e']

paired = ['#a6cee3',
 '#1f78b4',
 '#b2df8a',
 '#33a02c',
 '#fb9a99',
 '#e31a1c',
 '#fdbf6f',
 '#ff7f00',
 '#cab2d6',
 '#6a3d9a',
 '#b15928']
category20a = ['#1f77b4',
 '#aec7e8',
 '#ff7f0e',
 '#ffbb78',
 '#2ca02c',
 '#98df8a',
 '#d62728',
 '#ff9896',
 '#9467bd',
 '#c5b0d5',
 '#8c564b',
 '#c49c94',
 '#e377c2',
 '#f7b6d2',
 '#7f7f7f',
 '#c7c7c7',
 '#bcbd22',
 '#dbdb8d',
 '#17becf',
 '#9edae5']
category20b = ['#393b79',
               '#5254a3',
               '#6b6ecf',
               '#9c9ede',
               '#637939',
               '#8ca252',
               '#b5cf6b',
               '#cedb9c',
               '#8c6d31',
               '#bd9e39',
               '#e7ba52',
               '#e7cb94',
               '#843c39',
               '#ad494a',
               '#d6616b',
               '#e7969c',
               '#7b4173',
               '#a55194',
               '#ce6dbd',
               '#de9ed6']
category20c = ['#3182bd',
 '#6baed6',
 '#9ecae1',
 '#c6dbef',
 '#e6550d',
 '#fd8d3c',
 '#fdae6b',
 '#fdd0a2',
 '#31a354',
 '#74c476',
 '#a1d99b',
 '#c7e9c0',
 '#756bb1',
 '#9e9ac8',
 '#bcbddc',
 '#dadaeb',
 '#636363',
 '#969696',
 '#bdbdbd',
 '#d9d9d9']

all_palettes = ["selah",
                "frieda",
                "honeycombe",
                "crepuscule",
                "juniper",
                "plath",
                "blonde",
                "leather",
                "gucci",
                "sandbar",
                "fiestaware",
                "chilaquiles",
                "eleven",
                "splenda",
                "gremlin",
                "pollen",
                "medium",
                "juniper",
                "polya",
                "ostrich",
                "fraiche",
                "cheshire",
                "carmine",
                "joan",
                "pinot",
                "addams",
                "minuit",
                "fugazi",
                "clementine",
                "leda",
                "pugsley",
                "bellhooks",
                "wes",
                "lysergic",
                "pepo",
                "reese",
                "lufte",
                "oolong",
                "pitaya",
                "alice",
                "neko",
                "belle",
                "spiff",
                "yoshi",
                "phoebe",
                "pam",
                "menthol",
                "dwight",
                "riley",
                "mona",
                "eeyore",
                "rainbow",
                "rory",
                "pudding",
                "marmalade",
                "polaris",
                "trefoil",
                "harmon",
                "abed",
                "shirley",
                "surely",
                "annie",
                "pierce",
                "britta",
                "strogatz",
                "lutz",
                "writhe",
                "peanuts",
                "naval",
                "maggie",
                "indomie",
                "mooonbow",
                "heliotrope",
                "roosh",
                "seafare",
                "quinone",
                "quinoline",
                "perl",
                "perl256",
                "orb",
                "orb256"
                "diverging",
                "bluefish",
                "joan256",
                "joker",
                "joker256",
                "rach",
                "rach256",
                "BuPu9",
                "BuPu256"
                "holst",
                "moxxi",
                "moxxi256",
                "salvia",
                "salvia256",
                "warble",
                "warble256",
                "waitomo",
                "waitomo256",
                "vylette",
                "vylette256",
                "pom",
                "pom256",
                "lava",
                "lava256",
                "pumpkin",
                "pumpkin256",
                "pinctada",
                "pinctada256",
                "nacre",
                "nacre256",
                "crest",
                "crest256",
                "blink",
                "blink256",
                "betan",
                "betan256",
                "rue",
                "rue256",
                "otterpop",
                "otterpop20",
                "otterpop256",
                "gummi",
                "gummi20",
                "gummi256",
                "emporium",
                "emporium256",
                "paired",
                "category20a",
                "category20b",
                "category20c",
               ]
